@@ -21,65 +21,58 @@
 
 #include "cervisiashell.h"
 
+#include <kactioncollection.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kedittoolbar.h>
 #include <khelpmenu.h>
-#include <kkeydialog.h>
-#include <klibloader.h>
 #include <klocale.h>
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
 #include <kmessagebox.h>
+#include <kshortcutsdialog.h>
+#include <kstandardaction.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
 #include <kurl.h>
 
 
 CervisiaShell::CervisiaShell( const char *name )
-  : KParts::MainWindow( name )
-  , m_part(0)
+  : m_part(0)
 {
+    setObjectName( name );
     setXMLFile( "cervisiashellui.rc" );
 
-    KLibFactory* factory = KLibLoader::self()->factory("libcervisiapart");
-    if( factory )
+    KPluginLoader loader("libcervisiapart");
+    if( KPluginFactory *factory = loader.factory() )
     {
-        m_part = static_cast<KParts::ReadOnlyPart*>(factory->create(this,
-                                      "cervisiaview", "KParts::ReadOnlyPart"));
+        m_part = factory->create< KParts::ReadOnlyPart >(this);
         if( m_part )
+        {
+            m_part->setObjectName( "cervisiaview" );
             setCentralWidget(m_part->widget());
+        }
     }
     else
     {
-        KMessageBox::detailedError(this, i18n("The Cervisia library could not be loaded."), 
-                                   KLibLoader::self()->lastErrorMessage());
-        kapp->quit();
+        KMessageBox::detailedError(this, i18n("The Cervisia library could not be loaded."),
+                                   loader.errorString());
+        qApp->quit();
         return;
     }
-    
+
     setupActions();
-    
+
     //
     // Magic needed for status texts
     //
-    actionCollection()->setHighlightingEnabled(true);
-    connect( actionCollection(), SIGNAL( actionStatusText(const QString &) ),
-             statusBar(), SLOT( message(const QString &) ) );
-    connect( actionCollection(), SIGNAL( clearStatusText() ),
-             statusBar(), SLOT( clear() ) );
-    m_part->actionCollection()->setHighlightingEnabled(true);
-    connect( m_part->actionCollection(), SIGNAL( actionStatusText(const QString &) ),
-             statusBar(), SLOT( message(const QString &) ) );
-    connect( m_part->actionCollection(), SIGNAL( clearStatusText() ),
-             statusBar(), SLOT( clear() ) );
-
     createGUI( m_part );
 
     // enable auto-save of toolbar/menubar/statusbar and window size settings
     // and apply the previously saved settings
     setAutoSaveSettings("MainWindow", true);
-    
+
     // if the session is restoring, we already read the settings
-    if( !kapp->isRestored() )
+    if( !kapp->isSessionRestored() )
         readSettings();
 }
 
@@ -92,25 +85,25 @@ void CervisiaShell::setupActions()
 {
     setStandardToolBarMenuEnabled( true );
 
-    KAction *action = KStdAction::configureToolbars( this, SLOT(slotConfigureToolBars()),
+    QAction *action = KStandardAction::configureToolbars( this, SLOT(slotConfigureToolBars()),
                                             actionCollection() );
     QString hint = i18n("Allows you to configure the toolbar");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = KStdAction::keyBindings( this, SLOT(slotConfigureKeys()),
+    action = KStandardAction::keyBindings( this, SLOT(slotConfigureKeys()),
                                       actionCollection() );
     hint = i18n("Allows you to customize the keybindings");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = KStdAction::quit( kapp, SLOT( quit() ), actionCollection() );
+    action = KStandardAction::quit( this, SLOT( close() ), actionCollection() );
     hint = i18n("Exits Cervisia");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     setHelpMenuEnabled(false);
-    (void) new KHelpMenu(this, instance()->aboutData(), false, actionCollection());
+    (void) new KHelpMenu(this, componentData().aboutData(), false, actionCollection());
 
     action = actionCollection()->action("help_contents");
     hint = i18n("Invokes the KDE help system with the Cervisia documentation");
@@ -137,37 +130,37 @@ void CervisiaShell::setupActions()
 void CervisiaShell::openURL()
 {
     if( !m_lastOpenDir.isEmpty() )
-        m_part->openURL(KURL::fromPathOrURL(m_lastOpenDir));
+        m_part->openUrl( KUrl( m_lastOpenDir ) );
 }
 
 
-void CervisiaShell::openURL(const KURL& url)
+void CervisiaShell::openURL(const KUrl& url)
 {
-    m_part->openURL(url);
+    m_part->openUrl(url);
 }
 
 
 void CervisiaShell::slotConfigureKeys()
 {
-    KKeyDialog dlg;
-    dlg.insert(actionCollection());
+    KShortcutsDialog dlg;
+    dlg.addCollection(actionCollection());
     if( m_part )
-        dlg.insert(m_part->actionCollection());
-        
+        dlg.addCollection(m_part->actionCollection());
+
     dlg.configure();
 }
 
 void CervisiaShell::slotConfigureToolBars()
 {
-    saveMainWindowSettings( KGlobal::config(), autoSaveGroup() );
-    KEditToolbar dlg( factory() );
+    saveMainWindowSettings( KGlobal::config()->group( autoSaveGroup() ) );
+    KEditToolBar dlg( factory() );
     connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(slotNewToolbarConfig()));
     dlg.exec();
 }
 
 void CervisiaShell::slotNewToolbarConfig()
 {
-    applyMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+    applyMainWindowSettings( KGlobal::config()->group( autoSaveGroup() ) );
 }
 
 bool CervisiaShell::queryExit()
@@ -177,45 +170,42 @@ bool CervisiaShell::queryExit()
 }
 
 
-void CervisiaShell::readProperties(KConfig* config)
-{   
-    m_lastOpenDir = config->readPathEntry("Current Directory");
-    
-    // if the session is restoring, make sure we open the URL 
+void CervisiaShell::readProperties(const KConfigGroup& config)
+{
+    m_lastOpenDir = config.readPathEntry("Current Directory", QString());
+
+    // if the session is restoring, make sure we open the URL
     // since it's not handled by main()
-    if( kapp->isRestored() )
+    if( kapp->isSessionRestored() )
         openURL();
 }
 
 
-void CervisiaShell::saveProperties(KConfig* config)
+void CervisiaShell::saveProperties(KConfigGroup & config)
 {
     // Save current working directory (if part was created)
     if( m_part )
     {
-        config->writePathEntry("Current Directory", m_part->url().path());
-    
+        config.writePathEntry("Current Directory", m_part->url().path());
+
         // write to disk
-        config->sync();
+        config.sync();
     }
 }
 
 
 void CervisiaShell::readSettings()
 {
-    KConfig* config = KGlobal::config(); 
-    config->setGroup("Session");
-    
-    readProperties(config);
+    KConfigGroup cg( KGlobal::config(), "Session");
+
+    readProperties(cg);
 }
 
 
 void CervisiaShell::writeSettings()
 {
-    KConfig* config = KGlobal::config();  
-    config->setGroup("Session");
-    
-    saveProperties(config);
+    KConfigGroup cg( KGlobal::config(), "Session");
+    saveProperties(cg);
 }
 
 
