@@ -15,32 +15,33 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
+#include "kcalresource.h"
 
 #include <typeinfo>
 #include <stdlib.h>
 
-#include <qdatetime.h>
-#include <qstring.h>
-#include <qptrlist.h>
+#include <QDateTime>
+#include <QString>
 
 #include <kdebug.h>
 #include <kurl.h>
 #include <kio/job.h>
+#include <kio/jobuidelegate.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include <libkcal/vcaldrag.h>
-#include <libkcal/vcalformat.h>
-#include <libkcal/icalformat.h>
-#include <libkcal/exceptions.h>
-#include <libkcal/incidence.h>
-#include <libkcal/event.h>
-#include <libkcal/todo.h>
-#include <libkcal/journal.h>
-#include <libkcal/filestorage.h>
+#include <kcal/vcaldrag.h>
+#include <kcal/vcalformat.h>
+#include <kcal/icalformat.h>
+#include <kcal/exceptions.h>
+#include <kcal/incidence.h>
+#include <kcal/event.h>
+#include <kcal/todo.h>
+#include <kcal/journal.h>
+#include <kcal/filestorage.h>
 
 #include <kabc/locknull.h>
 
@@ -52,9 +53,20 @@
 #include "kcalresourceconfig.h"
 #include "resourceprefs.h"
 
-#include "kcalresource.h"
+KCalResource::KCalResource()
+ : ResourceCached(), mLock( 0 )
+{
+  mPrefs = new KBB::ResourcePrefs;
 
-KCalResource::KCalResource( const KConfig* config )
+  KConfigSkeletonItem::List items = mPrefs->items();
+  KConfigSkeletonItem::List::Iterator it;
+  for( it = items.begin(); it != items.end(); ++it ) {
+    (*it)->setGroup( identifier() );
+  } 
+  init();
+}
+
+KCalResource::KCalResource( const KConfigGroup& config )
   : ResourceCached( config ), mLock( 0 )
 {
   mPrefs = new KBB::ResourcePrefs;
@@ -65,9 +77,7 @@ KCalResource::KCalResource( const KConfig* config )
     (*it)->setGroup( identifier() );
   }
 
-  if ( config ) {
-    readConfig( config );
-  }
+  readConfig( config );
 
   init();
 }
@@ -103,30 +113,30 @@ KBB::ResourcePrefs *KCalResource::prefs()
   return mPrefs;
 }
 
-void KCalResource::readConfig( const KConfig * )
+void KCalResource::readConfig( const KConfigGroup & )
 {
   mPrefs->readConfig();
 }
 
-void KCalResource::writeConfig( KConfig *config )
+void KCalResource::writeConfig( KConfigGroup &config )
 {
-  kdDebug() << "KCalResource::writeConfig()" << endl;
+  kDebug() << "KCalResource::writeConfig()";
 
   ResourceCalendar::writeConfig( config );
 
   mPrefs->writeConfig();
 }
 
-QString KCalResource::cacheFile()
+QString KCalResource::cacheFile() const
 {
-  QString file = locateLocal( "cache", "kcal/kresources/" + identifier() );
-  kdDebug() << "KCalResource::cacheFile(): " << file << endl;
+  QString file = KStandardDirs::locateLocal( "cache", "kcal/kresources/" + identifier() );
+  kDebug() << "KCalResource::cacheFile(): " << file;
   return file;
 }
 
 bool KCalResource::doOpen()
 {
-  kdDebug(5800) << "KCalResource::doOpen()" << endl;
+  kDebug(5800) << "KCalResource::doOpen()";
 
   mOpen = true;
 
@@ -135,40 +145,40 @@ bool KCalResource::doOpen()
 
 bool KCalResource::doLoad()
 {
-  kdDebug() << "KCalResource::doLoad()" << endl;
+  kDebug() << "KCalResource::doLoad()";
 
   if ( !mOpen ) return true;
 
   if ( mDownloadJob ) {
-    kdWarning() << "KCalResource::doLoad(): download still in progress."
+    kWarning() << "KCalResource::doLoad(): download still in progress."
                 << endl;
     return false;
   }
   if ( mUploadJob ) {
-    kdWarning() << "KCalResource::doLoad(): upload still in progress."
+    kWarning() << "KCalResource::doLoad(): upload still in progress."
                 << endl;
     return false;
   }
 
-  mCalendar.close();
+  calendar()->close();
 
-  mCalendar.load( cacheFile() );
+  calendar()->load( cacheFile() );
 
   BugSystem *kbb = BugSystem::self();
 
-  kdDebug() << "KNOWN SERVERS:" << endl;
-  QValueList<BugServer *> servers = kbb->serverList();
-  QValueList<BugServer *>::ConstIterator it;
+  kDebug() << "KNOWN SERVERS:";
+  QList<BugServer *> servers = kbb->serverList();
+  QList<BugServer *>::ConstIterator it;
   for( it = servers.begin(); it != servers.end(); ++it ) {
-    kdDebug() << "  " << (*it)->identifier() << endl;
+    kDebug() << "  " << (*it)->identifier();
   }
 
   kbb->setCurrentServer( mPrefs->server() );
   if ( !kbb->server() ) {
-    kdError() << "Server not found." << endl;
+    kError() << "Server not found." << endl;
     return false;
   } else {
-    kdDebug() << "CURRENT SERVER: " << kbb->server()->identifier() << endl;
+    kDebug() << "CURRENT SERVER: " << kbb->server()->identifier();
   }
 
   kbb->retrievePackageList();
@@ -188,26 +198,26 @@ bool KCalResource::doLoad()
 void KCalResource::slotBugListAvailable( const Package &, const QString &,
                                          const Bug::List &bugs )
 {
-  kdDebug() << "KCalResource::slotBugListAvailable()" << endl;
+  kDebug() << "KCalResource::slotBugListAvailable()";
 
   if ( bugs.isEmpty() ) return;
 
   QString masterUid = "kbb_" + BugSystem::self()->server()->identifier();
-  KCal::Todo *masterTodo = mCalendar.todo( masterUid );
+  KCal::Todo *masterTodo = calendar()->todo( masterUid );
   if ( !masterTodo ) {
     masterTodo = new KCal::Todo;
     masterTodo->setUid( masterUid );
     masterTodo->setSummary( resourceName() );
-    mCalendar.addTodo( masterTodo );
+    calendar()->addTodo( masterTodo );
   }
 
   Bug::List::ConstIterator it;
   for( it = bugs.begin(); it != bugs.end(); ++it ) {
     Bug bug = *it;
-    kdDebug() << "  Bug " << bug.number() << ": " << bug.title() << endl;
+    kDebug() << "  Bug " << bug.number() << ": " << bug.title();
     QString uid = "KBugBuster_" + bug.number();
     KCal::Todo *newTodo = 0;
-    KCal::Todo *todo = mCalendar.todo( uid );
+    KCal::Todo *todo = calendar()->todo( uid );
     if ( !todo ) {
       newTodo = new KCal::Todo;
       newTodo->setUid( uid );
@@ -219,7 +229,7 @@ void KCalResource::slotBugListAvailable( const Package &, const QString &,
     todo->setSummary( bug.number() + ": " + bug.title() );
     todo->setRelatedTo( masterTodo );
 
-    if ( newTodo ) mCalendar.addTodo( newTodo );
+    if ( newTodo ) calendar()->addTodo( newTodo );
   }
 
   emit resourceChanged( this );
@@ -228,12 +238,12 @@ void KCalResource::slotBugListAvailable( const Package &, const QString &,
 void KCalResource::slotLoadJobResult( KIO::Job *job )
 {
   if ( job->error() ) {
-    job->showErrorDialog( 0 );
+    job->ui()->showErrorMessage();
   } else {
-    kdDebug() << "KCalResource::slotLoadJobResult() success" << endl;
+    kDebug() << "KCalResource::slotLoadJobResult() success";
 
-    mCalendar.close();
-    mCalendar.load( cacheFile() );
+    calendar()->close();
+    calendar()->load( cacheFile() );
 
     emit resourceChanged( this );
   }
@@ -245,7 +255,7 @@ void KCalResource::slotLoadJobResult( KIO::Job *job )
 
 bool KCalResource::doSave()
 {
-  kdDebug() << "KCalResource::doSave()" << endl;
+  kDebug() << "KCalResource::doSave()";
 
   if ( !mOpen ) return true;
 
@@ -255,21 +265,21 @@ bool KCalResource::doSave()
   }
 
   if ( mDownloadJob ) {
-    kdWarning() << "KCalResource::save(): download still in progress."
+    kWarning() << "KCalResource::save(): download still in progress."
                 << endl;
     return false;
   }
   if ( mUploadJob ) {
-    kdWarning() << "KCalResource::save(): upload still in progress."
+    kWarning() << "KCalResource::save(): upload still in progress."
                 << endl;
     return false;
   }
 
-  mCalendar.save( cacheFile() );
+  calendar()->save( cacheFile() );
 
-  mUploadJob = KIO::file_copy( KURL( cacheFile() ), mUploadUrl, -1, true );
-  connect( mUploadJob, SIGNAL( result( KIO::Job * ) ),
-           SLOT( slotSaveJobResult( KIO::Job * ) ) );
+  mUploadJob = KIO::file_copy( KUrl( cacheFile() ), mUploadUrl, -1, KIO::Overwrite );
+  connect( mUploadJob, SIGNAL( result( KJob * ) ),
+           SLOT( slotSaveJobResult( KJob * ) ) );
 
   return true;
 }
@@ -279,12 +289,12 @@ bool KCalResource::isSaving()
   return mUploadJob;
 }
 
-void KCalResource::slotSaveJobResult( KIO::Job *job )
+void KCalResource::slotSaveJobResult( KJob *job )
 {
   if ( job->error() ) {
-    job->showErrorDialog( 0 );
+    static_cast<KIO::Job*>(job)->ui()->showErrorMessage();
   } else {
-    kdDebug() << "KCalResource::slotSaveJobResult() success" << endl;
+    kDebug() << "KCalResource::slotSaveJobResult() success";
   }
 
   mUploadJob = 0;
@@ -296,7 +306,7 @@ void KCalResource::doClose()
 {
   if ( !mOpen ) return;
 
-  mCalendar.close();
+  calendar()->close();
   mOpen = false;
 }
 
@@ -308,9 +318,9 @@ KABC::Lock *KCalResource::lock()
 void KCalResource::dump() const
 {
   ResourceCalendar::dump();
-  kdDebug(5800) << "  DownloadUrl: " << mDownloadUrl.url() << endl;
-  kdDebug(5800) << "  UploadUrl: " << mUploadUrl.url() << endl;
-  kdDebug(5800) << "  ReloadPolicy: " << mReloadPolicy << endl;
+  kDebug(5800) << "  DownloadUrl: " << mDownloadUrl.url();
+  kDebug(5800) << "  UploadUrl: " << mUploadUrl.url();
+  kDebug(5800) << "  ReloadPolicy: " << mReloadPolicy;
 }
 
 #include "kcalresource.moc"
