@@ -12,23 +12,24 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
  * Configuration for KCachegrind
  */
 
+#include "configuration.h"
+
 #include <kconfig.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kconfiggroup.h>
 
-#include "configuration.h"
 #include "tracedata.h"
-#include "configdlgbase.h"
-
 #include "traceitemview.h"
+#include "ui_configdlgbase.h"
 
 //
 // Some predefined cost types...
@@ -49,16 +50,16 @@ static QStringList knownTypes()
 }
 
 
-static QString knownFormula(QString name)
+static QString knownFormula(const QString& name)
 {
   if (name =="L1m") return QString("I1mr + D1mr + D1mw");
   if (name =="L2m") return QString("I2mr + D2mr + D2mw");
   if (name =="CEst") return QString("Ir + 10 L1m + 100 L2m");
 
-  return QString::null;
+  return QString();
 }
 
-static QString knownLongName(QString name)
+static QString knownLongName(const QString& name)
 {
     if (name == "Ir") return i18n("Instruction Fetch");
     if (name =="Dr") return i18n("Data Read Access");
@@ -76,12 +77,10 @@ static QString knownLongName(QString name)
     if (name =="L2m") return i18n("L2 Miss Sum");
     if (name =="CEst") return i18n("Cycle Estimation");
 
-    return QString::null;
+    return QString();
 }
 
 
-
-
 //
 // Configuration
 //
@@ -127,8 +126,8 @@ void Configuration::saveOptions(KConfig* kconfig)
   Configuration* c = config();
 
   // color options
-  KConfigGroup colorConfig(kconfig, QCString("CostColors"));
-  QDictIterator<ColorSetting> it( c->_colors );
+  KConfigGroup colorConfig(kconfig, "CostColors");
+  Q3DictIterator<ColorSetting> it( c->_colors );
   int count = 1;
   for( ; it.current(); ++it ) {
     if ( !(*it)->automatic ) {
@@ -144,21 +143,23 @@ void Configuration::saveOptions(KConfig* kconfig)
   colorConfig.writeEntry( "Count", count-1);
 
   // source options
-  KConfigGroup sourceConfig(kconfig, QCString("Source"));
-  sourceConfig.writeEntry("Dirs", c->_generalSourceDirs, ':');
-  QDictIterator<QStringList> it2( c->_objectSourceDirs );
+  KConfigGroup sourceConfig(kconfig, "Source");
+  // XXX joining the list with a custom separator without escaping is
+  // bogus. should use regular list entries.
+  sourceConfig.writeEntry("Dirs", c->_generalSourceDirs.join(":"));
+  Q3DictIterator<QStringList> it2( c->_objectSourceDirs );
   count = 1;
   for( ; it2.current(); ++it2 ) {
     sourceConfig.writeEntry( QString("Object%1").arg(count),
 			     it2.currentKey());
     sourceConfig.writeEntry( QString("Dirs%1").arg(count),
-			     *(*it2), ':');
+			     (*(*it2)).join(":"));
     count++;
   }
   sourceConfig.writeEntry( "Count", count-1);
 
   // general options
-  KConfigGroup generalConfig(kconfig, QCString("General"));
+  KConfigGroup generalConfig(kconfig, "General");
   generalConfig.writeEntry("ShowPercentage", c->_showPercentage);
   generalConfig.writeEntry("ShowExpanded", c->_showExpanded);
   generalConfig.writeEntry("ShowCycles", c->_showCycles);
@@ -171,19 +172,19 @@ void Configuration::saveOptions(KConfig* kconfig)
   generalConfig.writeEntry("Context", c->_context);
   generalConfig.writeEntry("NoCostInside", c->_noCostInside);
 
-  KConfigGroup ctConfig(kconfig, QCString("CostTypes"));
-  int ctCount = TraceCostType::knownTypeCount();
+  KConfigGroup ctConfig(kconfig, "CostTypes");
+  int ctCount = TraceEventType::knownTypeCount();
   ctConfig.writeEntry( "Count", ctCount);
   for (int i=0; i<ctCount; i++) {
-    TraceCostType* t = TraceCostType::knownType(i);
+    TraceEventType* t = TraceEventType::knownType(i);
     ctConfig.writeEntry( QString("Name%1").arg(i+1), t->name());
 
     // Use localized key
-    TraceItemView::writeConfigEntry(&ctConfig,
+    TraceItemView::writeConfigEntry(ctConfig,
                                     QString("Longname%1").arg(i+1).ascii(),
                                     t->longName(),
                                     knownLongName(t->name()).utf8().data() /*, true */ );
-    TraceItemView::writeConfigEntry(&ctConfig,
+    TraceItemView::writeConfigEntry(ctConfig,
                                     QString("Formula%1").arg(i+1).ascii(),
                                     t->formula(), knownFormula(t->name()).utf8().data());
   }
@@ -214,11 +215,11 @@ void Configuration::readOptions(KConfig* kconfig)
   c->color("CostType-Dr")->color = QColor(40,40,180);
   c->color("CostType-Dw")->color = QColor(80,80,120);
 
-  KConfigGroup colorConfig(kconfig, QCString("CostColors"));
-  count = colorConfig.readNumEntry("Count", 0);
+  KConfigGroup colorConfig(kconfig, "CostColors");
+  count = colorConfig.readEntry("Count", 0);
   for (i=1;i<=count;i++) {
-    QString n = colorConfig.readEntry(QString("Name%1").arg(i));
-    QColor color = colorConfig.readColorEntry(QString("Color%1").arg(i));
+    QString n = colorConfig.readEntry(QString("Name%1").arg(i),QString());
+    QColor color = colorConfig.readEntry(QString("Color%1").arg(i), QColor(Qt::black));
 
     if (n.isEmpty()) continue;
 
@@ -233,16 +234,16 @@ void Configuration::readOptions(KConfig* kconfig)
   }
 
   // source options
-  KConfigGroup sourceConfig(kconfig, QCString("Source"));
+  KConfigGroup sourceConfig(kconfig, "Source");
   QStringList dirs;
-  dirs = sourceConfig.readListEntry("Dirs", ':');
+  dirs = sourceConfig.readEntry("Dirs", QString()).split(':');
   if (dirs.count()>0) c->_generalSourceDirs = dirs;
-  count = sourceConfig.readNumEntry("Count", 0);
+  count = sourceConfig.readEntry("Count", 0);
   c->_objectSourceDirs.clear();
   if (count>17) c->_objectSourceDirs.resize(count);
   for (i=1;i<=count;i++) {
-    QString n = sourceConfig.readEntry(QString("Object%1").arg(i));
-    dirs = sourceConfig.readListEntry(QString("Dirs%1").arg(i), ':');
+    QString n = sourceConfig.readEntry(QString("Object%1").arg(i),QString());
+    dirs = sourceConfig.readEntry(QString("Dirs%1").arg(i), QString()).split(':');
 
     if (n.isEmpty() || (dirs.count()==0)) continue;
 
@@ -251,47 +252,47 @@ void Configuration::readOptions(KConfig* kconfig)
 
 
   // general options
-  KConfigGroup generalConfig(kconfig, QCString("General"));
-  c->_showPercentage = generalConfig.readBoolEntry("ShowPercentage", true);
-  c->_showExpanded = generalConfig.readBoolEntry("ShowExpanded", false);
-  c->_showCycles = generalConfig.readBoolEntry("ShowCycles", true);
-  c->_cycleCut = generalConfig.readDoubleNumEntry("CycleCut", 0.0);
-  c->_maxSymbolCount = generalConfig.readNumEntry("MaxSymbolCount", 10);
-  c->_maxListCount = generalConfig.readNumEntry("MaxListCount", 100);
-  c->_maxSymbolLength = generalConfig.readNumEntry("MaxSymbolLength", 30);
-  c->_percentPrecision = generalConfig.readNumEntry("PercentPrecision", 2);
+  KConfigGroup generalConfig(kconfig, "General");
+  c->_showPercentage = generalConfig.readEntry("ShowPercentage", true);
+  c->_showExpanded = generalConfig.readEntry("ShowExpanded", false);
+  c->_showCycles = generalConfig.readEntry("ShowCycles", true);
+  c->_cycleCut = generalConfig.readEntry("CycleCut", 0.0);
+  c->_maxSymbolCount = generalConfig.readEntry("MaxSymbolCount", 10);
+  c->_maxListCount = generalConfig.readEntry("MaxListCount", 100);
+  c->_maxSymbolLength = generalConfig.readEntry("MaxSymbolLength", 30);
+  c->_percentPrecision = generalConfig.readEntry("PercentPrecision", 2);
 
-  c->_context = generalConfig.readNumEntry("Context", 3);
-  c->_noCostInside   = generalConfig.readNumEntry("NoCostInside", 20);
+  c->_context = generalConfig.readEntry("Context", 3);
+  c->_noCostInside   = generalConfig.readEntry("NoCostInside", 20);
 
   // known cost types
-  if (TraceCostType::knownTypeCount()==0) {
+  if (TraceEventType::knownTypeCount()==0) {
 
-    KConfigGroup ctConfig(kconfig, QCString("CostTypes"));
-    int ctCount = ctConfig.readNumEntry("Count", 0);
+    KConfigGroup ctConfig(kconfig, "CostTypes");
+    int ctCount = ctConfig.readEntry("Count", 0);
     if (ctCount>0) {
       for (int i=1;i<=ctCount;i++) {
-        QString n = ctConfig.readEntry(QString("Name%1").arg(i));
-        QString l = ctConfig.readEntry(QString("Longname%1").arg(i));
+        QString n = ctConfig.readEntry(QString("Name%1").arg(i),QString());
+        QString l = ctConfig.readEntry(QString("Longname%1").arg(i),QString());
 	if (l.isEmpty()) l = knownLongName(n);
-        QString f = ctConfig.readEntry(QString("Formula%1").arg(i));
+        QString f = ctConfig.readEntry(QString("Formula%1").arg(i), QString());
 	if (f.isEmpty()) f = knownFormula(n);
 
-        TraceCostType::add(new TraceCostType(n, l, f));
+        TraceEventType::add(new TraceEventType(n, l, f));
       }
     }
     else {
       // add default types
 
       QString longName, formula;
-      TraceCostType* ct;
+      TraceEventType* ct;
       QStringList l = knownTypes();
       for ( QStringList::Iterator it = l.begin();
             it != l.end(); ++it ) {
         longName = knownLongName(*it);
         formula  = knownFormula(*it);
-        ct = new TraceCostType(*it, longName, formula);
-        TraceCostType::add(ct);
+        ct = new TraceEventType(*it, longName, formula);
+        TraceEventType::add(ct);
       }
     }
   }
@@ -304,12 +305,12 @@ QColor Configuration::groupColor(TraceItem* cost)
   if (!cost)
     n = QString("default");
   else
-    n = TraceCost::typeName(cost->type()) + "-" + cost->prettyName();
+    n = TraceCost::typeName(cost->type()) + '-' + cost->prettyName();
 
   return color(n)->color;
 }
 
-QColor Configuration::costTypeColor(TraceCostType* t)
+QColor Configuration::eventTypeColor(TraceEventType* t)
 {
    QString n;
 
@@ -338,8 +339,8 @@ QColor Configuration::functionColor(TraceCost::CostType gt,
   if (group != f) {
     // first look for manual color of a function in a group
     n = TraceCost::typeName(group->type()) +
-        "-" + group->prettyName() +
-        "-" + f->prettyName();
+        '-' + group->prettyName() +
+        '-' + f->prettyName();
 
     ColorSetting* cs = color(n, false);
     if (cs) return cs->color;
@@ -347,7 +348,7 @@ QColor Configuration::functionColor(TraceCost::CostType gt,
   return groupColor(group);
 }
 
-Configuration::ColorSetting* Configuration::color(QString n, bool createNew)
+Configuration::ColorSetting* Configuration::color(const QString& n, bool createNew)
 {
 //  qDebug("Color for %s", n.latin1());
 
@@ -396,14 +397,14 @@ QStringList Configuration::sourceDirs(TraceData* data, TraceObject* o)
     }
     if (!ol) continue;
 
-    for(unsigned int i=0;i<ol->count();i++)
+    for(int i=0;i<ol->count();i++)
       l.prepend( (*ol)[i] );
   }
   if (ol2) {
-    for(unsigned int i=0;i<ol2->count();i++)
+    for(int i=0;i<ol2->count();i++)
       l.prepend( (*ol2)[i] );
   }
-  if (0) kdDebug() << "Configuration::sourceDirs: " << l.join(":") << endl;
+  if (0) kDebug() << "Configuration::sourceDirs: " << l.join(":");
 
   return l;
 }
@@ -462,11 +463,11 @@ int Configuration::maxSymbolLength()
   return config()->_maxSymbolLength;
 }
 
-QString Configuration::shortenSymbol(QString s)
+QString Configuration::shortenSymbol(const QString& s)
 {
-    if ((int)s.length() > maxSymbolLength())
-	s = s.left(maxSymbolLength()) + "...";
-    return s;
+	if ((int)s.length() > maxSymbolLength())
+		return s.left(maxSymbolLength()) + "...";
+	return s;
 }
 
 int Configuration::maxListCount()
