@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -24,9 +24,9 @@
 #define TOPLEVEL_H
 
 #include <qdatetime.h>
+#include <QLabel>
 
-#include <dcopobject.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 #include "traceitemview.h"
 #include "tracedata.h"
@@ -36,9 +36,9 @@ class QLineEdit;
 class QDockWidget;
 class QLabel;
 class QProgressBar;
-class QPopupMenu;
+class QMenu;
 
-class KURL;
+class KUrl;
 class KSelectAction;
 class KToggleAction;
 class KToolBarPopupAction;
@@ -52,26 +52,26 @@ class DumpSelection;
 class StackSelection;
 class TraceFunction;
 
-class TopLevel : public KMainWindow, public DCOPObject
+class TopLevel : public KXmlGuiWindow
 {
   Q_OBJECT
-
+  Q_CLASSINFO("D-Bus Interface", "org.kde.kcachegrind")
 public:
-  TopLevel(const char *name = 0);
+  TopLevel();
   ~TopLevel();
 
   TraceData* data() { return _data; }
   void setData(TraceData*);
 
-  virtual void saveProperties(KConfig*);
-  virtual void readProperties(KConfig*);
+  virtual void saveProperties(KConfigGroup &);
+  virtual void readProperties(const KConfigGroup &);
 
   void createActions();
   void createDocks();
 
   TraceItem::CostType groupType() { return _groupType; }
-  TraceCostType* costType() { return _costType; }
-  TraceCostType* costType2() { return _costType2; }
+  TraceEventType* eventType() { return _eventType; }
+  TraceEventType* eventType2() { return _eventType2; }
   TracePartList activeParts() { return _activeParts; }
   TracePartList hiddenParts() { return _hiddenParts; }
 
@@ -81,16 +81,16 @@ public:
   bool showCycles() const { return _showCycles; }
 
   /* convenience functions for often used context menu items */
-  void addCostMenu(QPopupMenu*,bool);
-  void addGoMenu(QPopupMenu*);
+  void addEventTypeMenu(QMenu*,bool);
+  void addGoMenu(QMenu*);
 
 public slots:
   void newTrace();
   void loadTrace();
-  void loadTrace(const KURL&);
+  void loadTrace(const KUrl&);
   void loadTrace(QString);
   void addTrace();
-  void addTrace(const KURL&);
+  void addTrace(const KUrl&);
   void addTrace(QString);
 
   // for quick showing the main window...
@@ -113,8 +113,8 @@ public slots:
   void updateLayoutActions();
 
   void updateStatusBar();
-  void costTypeSelected(const QString&);
-  void costType2Selected(const QString&);
+  void eventTypeSelected(const QString&);
+  void eventType2Selected(const QString&);
   void groupTypeSelected(int);
   void splitSlot();
   void splitDirSlot();
@@ -140,18 +140,18 @@ public slots:
   void forceTrace();
   void forceTraceReload();
   void forwardAboutToShow();
+  void forwardTriggered(QAction*);
   void backAboutToShow();
+  void backTriggered(QAction*);
   void upAboutToShow();
-  void forwardActivated(int);
-  void backActivated(int);
-  void upActivated(int);
+  void upTriggered(QAction*);
 
-  bool setCostType(TraceCostType*);
-  bool setCostType2(TraceCostType*);
-  bool setCostType(QString);
-  bool setCostType2(QString);
-  bool setCostType(int);
-  bool setCostType2(int);
+  bool setEventType(TraceEventType*);
+  bool setEventType2(TraceEventType*);
+  bool setEventType(QString);
+  bool setEventType2(QString);
+  bool setEventType(QAction*);
+  bool setEventType2(QAction*);
   bool setGroupType(TraceItem::CostType);
   bool setGroupType(QString);
   bool setGroup(TraceCostItem*);
@@ -164,10 +164,10 @@ public slots:
 
   /* These go back to mainloop first by using a timer.
    * So they can be called from event handlers that
-   * aren't allowed to delete list entries.
+   * are not allowed to delete list entries.
    */
-  void setCostTypeDelayed(TraceCostType*);
-  void setCostType2Delayed(TraceCostType*);
+  void setEventTypeDelayed(TraceEventType*);
+  void setEventType2Delayed(TraceEventType*);
   void setGroupTypeDelayed(TraceItem::CostType);
   void setGroupDelayed(TraceCostItem*);
   void setTraceItemDelayed(TraceItem*);
@@ -179,8 +179,8 @@ public slots:
   void setDirectionDelayed(TraceItemView::Direction);
 
   /* SingleShot Slots (without parameters) for the delayed versions */
-  void setCostTypeDelayed();
-  void setCostType2Delayed();
+  void setEventTypeDelayed();
+  void setEventType2Delayed();
   void setGroupTypeDelayed();
   void setGroupDelayed();
   void setTraceItemDelayed();
@@ -195,8 +195,11 @@ public slots:
   void slotShowTip();
 
   // progress in status bar, empty message disables progress display
-  void showStatus(QString msg, int progress);
+  void showStatus(const QString& msg, int progress);
   void showMessage(const QString&, int msec);
+  // messages from file loader
+  void showLoadError(const QString&,int,const QString&);
+  void showLoadWarning(const QString&,int,const QString&);
 
 private:
   void init();
@@ -204,8 +207,8 @@ private:
   void createMiscActions();
   void setupMainWidget(MainWidget*);
   void setupPartSelection(PartSelection*);
-  void restoreCurrentState(QString postfix);
-  void saveCurrentState(QString postfix);
+  void restoreCurrentState(const QString& postfix);
+  void saveCurrentState(const QString& postfix);
   void saveTraceSettings();
   QString traceKey();
   void restoreTraceTypes();
@@ -215,7 +218,7 @@ private:
   QLabel* _statusLabel;
   KRecentFilesAction* _openRecent;
   bool _twoMainWidgets;
-  Orientation _spOrientation;
+  Qt::Orientation _spOrientation;
 
   MultiView* _multiView;
   FunctionSelection* _functionSelection;
@@ -224,7 +227,7 @@ private:
   StackSelection* _stackSelection;
   QLineEdit* queryLineEdit;
 
-  QDockWindow *_partDock, *_stackDock, *_functionDock, *_dumpDock;
+  QDockWidget *_partDock, *_stackDock, *_functionDock, *_dumpDock;
   bool _forcePartDock;
 
   KSelectAction *_saCost, *_saCost2, *saGroup;
@@ -239,9 +242,9 @@ private:
 
   // trace data shown in this window
   TraceData* _data;
-  // subcost types used for visualisation
-  TraceCostType* _costType;
-  TraceCostType* _costType2;
+  // subcost types used for visualization
+  TraceEventType* _eventType;
+  TraceEventType* _eventType2;
   // grouping of function list
   TraceItem::CostType _groupType;
   // selected group
@@ -254,8 +257,8 @@ private:
   int _layoutCurrent, _layoutCount;
 
   // for delayed slots
-  TraceCostType* _costTypeDelayed;
-  TraceCostType* _costType2Delayed;
+  TraceEventType* _eventTypeDelayed;
+  TraceEventType* _eventType2Delayed;
   TraceItem::CostType _groupTypeDelayed;
   TraceCostItem* _groupDelayed;
   TraceItem* _traceItemDelayed;
