@@ -1,18 +1,20 @@
-#include <qintdict.h>
+#include <q3intdict.h>
+//Added by qt3to4:
 #include <stdio.h>
 #include <qstringlist.h>
-#include <qstrlist.h>
+#include <q3strlist.h>
 #include <qtextstream.h>
-#include <qsortedlist.h>
+#include <q3sortedlist.h>
 #include <qfile.h>
-#include <qtl.h>
-#include <qvaluelist.h>
+#include <q3tl.h>
+#include <q3valuelist.h>
+#include <Q3CString>
 #include <stdlib.h>
-#include <ktempfile.h>
-#include <kinstance.h>
+#include <ktemporaryfile.h>
+#include <kcomponentdata.h>
 #include <kstandarddirs.h>
 #include <kcmdlineargs.h>
-#include <kprocess.h>
+#include <kshell.h>
 
 extern "C" {
 /* Options passed to cplus_demangle (in 2nd parameter). */
@@ -48,11 +50,11 @@ struct Entry {
   bool operator<(const Entry &e) { return total_size > e.total_size; }
 };
 
-QIntDict<Entry> *entryDict = 0;
-QIntDict<char> *symbolDict = 0;
-QIntDict<char> *formatDict = 0;
-QSortedList<Entry> *entryList = 0;
-QStrList *excludes = 0;
+Q3IntDict<Entry> *entryDict = 0;
+Q3IntDict<char> *symbolDict = 0;
+Q3IntDict<char> *formatDict = 0;
+Q3SortedList<Entry> *entryList = 0;
+Q3StrList *excludes = 0;
 
 const char * const unknown = "<unknown>";
 const char * const excluded = "<excluded>";
@@ -66,18 +68,18 @@ int totalBytes = 0;
 int maxBytes;
 
 int fromHex(const char *str);
-void parseLine(const QCString &_line, char operation);
+void parseLine(const QString &_line, char operation);
 void dumpBlocks();
 
 int fromHex(const char *str)
 {
    if (*str == '[') str++;
    str += 2; // SKip "0x"
-   return strtol(str, NULL, 16);
+   return strtoll(str, NULL, 16);
 }
 
 // [address0][address1] .... [address] + base size
-void parseLine(const QCString &_line, char operation)
+void parseLine(const QString &_line, char operation)
 {
   char *line= (char *) _line.data();
   const char *cols[200];
@@ -147,7 +149,7 @@ void parseLine(const QCString &_line, char operation)
 
 void sortBlocks()
 {
-   QIntDictIterator<Entry> it(*entryDict);
+   Q3IntDictIterator<Entry> it(*entryDict);
    for(;it.current(); ++it)
    {
       Entry *entry = it.current();
@@ -164,8 +166,8 @@ void sortBlocks()
 
 void collectDupes()
 {
-   QIntDict<Entry> dupeDict;
-   QIntDictIterator<Entry> it(*entryDict);
+   Q3IntDict<Entry> dupeDict;
+   Q3IntDictIterator<Entry> it(*entryDict);
    for(;it.current();)
    {
       Entry *entry = it.current();
@@ -244,30 +246,32 @@ int lookupSymbols(FILE *stream)
 
 void lookupUnknownSymbols(const char *appname)
 {
-   KTempFile inputFile;
-   KTempFile outputFile;
-   inputFile.setAutoDelete(true);
-   outputFile.setAutoDelete(true);
-   FILE *fInputFile = inputFile.fstream();
-   QIntDict<char> oldDict = *symbolDict;
-   QIntDictIterator<char> it(oldDict);
+   KTemporaryFile inputFile;
+   KTemporaryFile outputFile;
+   inputFile.open();
+   outputFile.open();
+   QTextStream str ( &inputFile );
+   Q3IntDict<char> oldDict = *symbolDict;
+   Q3IntDictIterator<char> it(oldDict);
    for(;it.current(); ++it)
    {
-       fprintf(fInputFile, "%08lx\n", it.currentKey());
+       QString temp;
+       temp.sprintf("%08lx\n", it.currentKey());
+       str << temp;
    }
-   inputFile.close();
-   QCString command;
+   str.flush();
+   Q3CString command;
    command.sprintf("addr2line -e %s -f -C -s < %s > %s", appname,
-	QFile::encodeName(KProcess::quote(inputFile.name())).data(),
-	QFile::encodeName(KProcess::quote(outputFile.name())).data());
+	QFile::encodeName(KShell::quoteArg(inputFile.fileName())).data(),
+	QFile::encodeName(KShell::quoteArg(outputFile.fileName())).data());
    system(command.data());
-   fInputFile = fopen(QFile::encodeName(outputFile.name()), "r");
+   FILE *fInputFile = fopen(QFile::encodeName(outputFile.fileName()), "r");
    if (!fInputFile)
    {
       fprintf(stderr, "Error opening temp file.\n");
       return;
    }
-   QIntDictIterator<char> it2(oldDict);
+   Q3IntDictIterator<char> it2(oldDict);
    char buffer1[1024];
    char buffer2[1024];
    for(;it2.current(); ++it2)
@@ -282,7 +286,7 @@ void lookupUnknownSymbols(const char *appname)
       if (!fgets(buffer2, 1023, fInputFile)) continue;
       buffer1[strlen(buffer1)-1]=0;
       buffer2[strlen(buffer2)-1]=0;
-      QCString symbol;
+      Q3CString symbol;
       symbol.sprintf("%s(%s)", buffer2, buffer1);
       if(*buffer1 != '?')
           symbolDict->replace(it2.currentKey(),qstrdup(symbol.data()));
@@ -310,7 +314,7 @@ const char *lookupAddress(int addr)
 {
    char *str = formatDict->find(addr);
    if (str) return str;
-   QCString s = symbolDict->find(addr);
+   QByteArray s = symbolDict->find(addr);
    if (s.isEmpty())
    {
 fprintf(stderr, "Error!\n");
@@ -324,7 +328,7 @@ fprintf(stderr, "Error!\n");
         end = s.findRev(')');
      if ((start > 0) && (end > start))
      {
-       QCString symbol = s.mid(start+1, end-start-1);
+       QByteArray symbol = s.mid(start+1, end-start-1);
        char *res = 0;
        if (symbol.find(')') == -1)
            res = cplus_demangle(symbol.data(), DMGL_PARAMS | DMGL_AUTO | DMGL_ANSI );
@@ -390,7 +394,7 @@ struct TreeEntry
    int address;			// backtrace
    int total_size;
    int total_count;
-   typedef QValueList < TreeEntry > TreeList;
+   typedef Q3ValueList < TreeEntry > TreeList;
    TreeList *subentries () const;
    mutable TreeList *_subentries;
    TreeEntry (int adr = 0, int size = 0, int count = 0, TreeList * sub = NULL );
@@ -398,7 +402,7 @@ struct TreeEntry
    bool operator < (const TreeEntry &) const;
 };
 
-typedef QValueList < TreeEntry > TreeList;
+typedef Q3ValueList < TreeEntry > TreeList;
 
 inline TreeEntry::TreeEntry (int adr, int size, int count, TreeList * sub)
  : address (adr), total_size (size), total_count (count), _subentries (sub)
@@ -523,9 +527,9 @@ void dumpTree (FILE * file)
       dumpTree (*it, 0, indent, file);
 }
 
-void createTree (const QCString & treefile, int threshold, int maxdepth)
+void createTree (const QString & treefile, int threshold, int maxdepth)
 {
-   FILE * file = fopen (treefile, "w");
+   FILE * file = fopen (treefile.toLocal8Bit(), "w");
    if (file == NULL)
    {
       fprintf (stderr, "Can't write tree file.\n");
@@ -558,29 +562,36 @@ void readExcludeFile(const char *name)
    excludes->sort();
 }
 
-static KCmdLineOptions options[] =
-{
-  { "x", 0, 0 },
-  { "exclude <file>", "File containing symbols to exclude from output", 0},
-  { "e", 0, 0 },
-  { "exe <file>", "Executable to use for looking up unknown symbols", 0},
-  { "+<trace-log>", "Log file to investigate", 0},
-  {"t", 0, 0},
-  {"tree <file>", "File to write allocations tree", 0},
-  {"th", 0, 0},
-  {"treethreshold <value>",
-    "Don't print subtrees which allocated less than <value> memory", 0},
-  {"td", 0, 0},
-  {"treedepth <value>",
-    "Don't print subtrees that are deeper than <value>", 0},
-  KCmdLineLastOption
-};
-
 int main(int argc, char *argv[])
 {
-  KInstance instance("kmtrace");
+  KComponentData componentData("kmtrace");
 
-  KCmdLineArgs::init(argc, argv, "kmtrace", "KDE Memory leak tracer", "v1.0");
+  KCmdLineArgs::init(argc, argv, "kmtrace", 0, ki18n("kmtrace"), "v1.0", ki18n("KDE Memory leak tracer"));
+
+
+  KCmdLineOptions options;
+
+  options.add("x");
+
+  options.add("exclude <file>", ki18n("File containing symbols to exclude from output"));
+
+  options.add("e");
+
+  options.add("exe <file>", ki18n("Executable to use for looking up unknown symbols"));
+
+  options.add("+<trace-log>", ki18n("Log file to investigate"));
+
+  options.add("t");
+
+  options.add("tree <file>", ki18n("File to write allocations tree"));
+
+  options.add("th");
+
+  options.add("treethreshold <value>", ki18n("Do not print subtrees which allocated less than <value> memory"));
+
+  options.add("td");
+
+  options.add("treedepth <value>", ki18n("Do not print subtrees that are deeper than <value>"));
 
   KCmdLineArgs::addCmdLineOptions(options);
 
@@ -589,20 +600,20 @@ int main(int argc, char *argv[])
   (void) args->count();
   const char *logfile;
   if(args->count())
-    logfile = args->arg(0);
+    logfile = args->arg(0).toLocal8Bit();
   else
     logfile = "ktrace.out";
 
-  QCString exe = args->getOption("exe");
-  QCString exclude;
+  QString exe = args->getOption("exe");
+  QByteArray exclude;
 
-  excludes = new QStrList;
+  excludes = new Q3StrList;
 
-  exclude = QFile::encodeName(locate("data", "kmtrace/kde.excludes"));
+  exclude = QFile::encodeName(KStandardDirs::locate("data", "kmtrace/kde.excludes"));
   if(!exclude.isEmpty())
       readExcludeFile(exclude);
 
-  exclude = args->getOption("exclude");
+  exclude = args->getOption("exclude").toLocal8Bit().data();
   if (!exclude.isEmpty())
   {
      fprintf(stderr, "Reading %s\n", exclude.data());
@@ -616,13 +627,13 @@ int main(int argc, char *argv[])
      exit(1);
   }
 
-  entryDict = new QIntDict<Entry>(9973);
-  symbolDict = new QIntDict<char>(9973);
-  formatDict = new QIntDict<char>(9973);
-  entryList = new QSortedList<Entry>;
+  entryDict = new Q3IntDict<Entry>(9973);
+  symbolDict = new Q3IntDict<char>(9973);
+  formatDict = new Q3IntDict<char>(9973);
+  entryList = new Q3SortedList<Entry>;
 
   fprintf(stderr, "Running\n");
-  QCString line;
+  QString line;
   char line2[1024];
   while(!feof(stream))
   {
@@ -636,20 +647,20 @@ int main(int argc, char *argv[])
      }
      else if (line2[0] == '#')
      {
-       QCString app(line2+1);
+       QByteArray app(line2+1);
        if(exe.isEmpty())
        {
-         exe = app.stripWhiteSpace();
+         exe = app.trimmed();
          fprintf(stderr, "ktrace.out: malloc trace of %s\n", exe.data());
        }
-       else if(!app.contains(exe.data()))
+       else if(!app.contains(exe.toLocal8Bit().data()))
        {
          fprintf(stderr, "trace file was for application '%s', not '%s'\n", app.data(), exe.data());
          exit(1);
        }
      }
      else if (line2[0] == '@')
-        line = 0;
+        line = QString();
      else if (line2[0] == '[')
         line = line + ' ' + line2;
      else if (line2[0] == '+')
@@ -657,7 +668,7 @@ int main(int argc, char *argv[])
         allocCount++;
         line = line + ' ' + line2;
         parseLine(line, '+');
-        line = 0;
+        line = QString();
         if (allocCount & 128)
         {
            fprintf(stderr, "\rTotal long term allocs: %d still allocated: %d   ", allocCount, entryDict->count());
@@ -667,13 +678,13 @@ int main(int argc, char *argv[])
      {
         line = line + ' ' + line2;
         parseLine(line, '-');
-        line = 0;
+        line = QString();
      }
      else if (line2[0] == '<')
      {
         line2[0] = '-';
         // First part of realloc (free)
-        QCString reline = line + ' ' + line2;
+        QString reline = line + ' ' + line2;
         parseLine(reline, '-');
      }
      else if (line2[0] == '>')
@@ -682,14 +693,14 @@ int main(int argc, char *argv[])
         // Second part of realloc (alloc)
         line = line + ' ' + line2;
         parseLine(line, '+');
-        line = 0;
+        line = QString();
      }
      else
      {
-        char *addr = index(line2,'[');
+        const char *addr = index(line2,'[');
         if (addr)
         {
-           line = line + ' ' + addr;
+           line = line + QChar(' ') + addr;
         }
      }
   }
@@ -706,10 +717,10 @@ int main(int argc, char *argv[])
   rewind(stream);
   lookupSymbols(stream);
   fprintf(stderr, "Looking up unknown symbols...\n");
-  lookupUnknownSymbols(exe);
+  lookupUnknownSymbols(exe.toLocal8Bit());
   fprintf(stderr, "Printing...\n");
   dumpBlocks();
-  QCString treeFile = args->getOption ("tree");
+  QString treeFile = args->getOption ("tree");
   if (!treeFile.isEmpty ())
   {
       fprintf (stderr, "Creating allocation tree...\n");
