@@ -1,11 +1,10 @@
 /***************************************************************************
-                                kompare_shell.cpp  -  description
-                                -------------------
+                                kompare_shell.cpp
+                                -----------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2004 Otto Bruggeman
-                                  (C) 2001-2003 John Firebaugh
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
+        Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
+        Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -16,37 +15,41 @@
 **   (at your option) any later version.
 **
 ***************************************************************************/
+#include "kompare_shell.h"
+
+#include <QtCore/QTextStream>
+#include <QtGui/QDockWidget>
 
 #include <ktexteditor/document.h>
-#include <ktexteditor/editinterface.h>
 #include <ktexteditor/view.h>
 #include <kdebug.h>
 #include <kedittoolbar.h>
 #include <kencodingfiledialog.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kparts/componentfactory.h>
 #include <ksqueezedtextlabel.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
-#include <ktrader.h>
-#include <kuserprofile.h>
+#include <kstandardaction.h>
+#include <kmimetypetrader.h>
+#include <kservicetypetrader.h>
+#include <ktoggleaction.h>
+// #include <kuserprofile.h>
+#include <kactioncollection.h>
 
 #include "kompare_part.h"
 #include "komparenavtreepart.h"
 #include "kompareurldialog.h"
 
-#include "kompare_shell.h"
-
 #define ID_N_OF_N_DIFFERENCES      1
 #define ID_N_OF_N_FILES            2
 #define ID_GENERAL                 3
 
 KompareShell::KompareShell()
-	: KParts::DockMainWindow( 0L, "KompareShell" ),
+	: KParts::MainWindow( 0L, "KompareShell" ),
 	m_textViewPart( 0 ),
 	m_textViewWidget( 0 )
 {
@@ -60,16 +63,17 @@ KompareShell::KompareShell()
 	setupActions();
 	setupStatusBar();
 
-	KTrader::OfferList offers = KTrader::self()->query( "text/x-diff",
-	    "Kompare/ViewPart", QString::null, QString::null );
-#ifdef NDEBUG
+	KService::List offers = KMimeTypeTrader::self()->query( "text/x-patch",
+                                                            "Kompare/ViewPart",
+                                                             QString() );
+#ifndef NDEBUG
 	for( int i = 0; i < offers.count(); i++ )
 	{
-		kdDebug(8102) << "One kservicetype checked..." << endl;
-		KService::Ptr ptr2 = *(offers.at( i ));
+		kDebug(8102) << "One kservicetype checked..." << endl;
+		KService::Ptr ptr2 = offers.at( i );
 		QStringList list = ptr2->serviceTypes();
 		for ( QStringList::Iterator it2 = list.begin(); it2 != list.end(); ++it2 )
-			kdDebug(8102) << *it2 << endl;
+			kDebug(8102) << *it2 << endl;
 	}
 #endif
 	if ( offers.count() == 0 )
@@ -83,17 +87,20 @@ KompareShell::KompareShell()
 	KLibFactory *mainViewFactory = KLibLoader::self()->factory( ptr->library().ascii() );
 	if (mainViewFactory)
 	{
-		m_mainViewDock = createDockWidget( "View", kapp->icon() );
+//		m_mainViewDock = new QDockWidget( i18n( "View" ), this );
+//		m_mainViewDock->setObjectName( "View" );
+// 		m_mainViewDock = createDockWidget( "View", qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)) );
 		// now that the Part is loaded, we cast it to a KomparePart to get
 		// our hands on it
-		m_viewPart = static_cast<KomparePart*>(mainViewFactory->create(m_mainViewDock,
-		              "kompare_part", "KParts::ReadWritePart" ));
+		m_viewPart = static_cast<KomparePart*>(mainViewFactory->create(this,
+		              "KomparePart", QStringList("KParts::ReadWritePart" )));
 
 		if ( m_viewPart )
 		{
-			m_mainViewDock->setWidget( m_viewPart->widget() );
-			setView( m_mainViewDock );
-			setMainDockWidget( m_mainViewDock );
+			setCentralWidget( m_viewPart->widget() );
+//			m_mainViewDock->setWidget( m_viewPart->widget() );
+// 			setView( m_mainViewDock );
+// 			setMainDockWidget( m_mainViewDock );
 
 			// and integrate the part's GUI with the shell's
 			createGUI(m_viewPart);
@@ -108,7 +115,7 @@ KompareShell::KompareShell()
 	}
 
 	offers.clear();
-	offers = KTrader::self()->query( "text/x-diff", "KParts/ReadOnlyPart", "'Kompare/NavigationPart' in ServiceTypes", QString::null );
+	offers = KServiceTypeTrader::self()->query( "KParts/ReadOnlyPart", "'Kompare/NavigationPart' in ServiceTypes" );
 	if ( offers.count() == 0 )
 	{
 		KMessageBox::error(this, i18n( "Could not find our KompareNavigationPart." ) );
@@ -120,15 +127,18 @@ KompareShell::KompareShell()
 	KLibFactory *navTreeFactory = KLibLoader::self()->factory( ptr->library().ascii() );
 	if (navTreeFactory)
 	{
-		m_navTreeDock = createDockWidget( "Navigation", kapp->icon() );
+		m_navTreeDock = new QDockWidget( i18n( "Navigation" ), this );
+		m_navTreeDock->setObjectName( "Navigation" );
+// 		m_navTreeDock = createDockWidget( "Navigation", qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)) );
 
 		m_navTreePart = static_cast<KompareNavTreePart*>(navTreeFactory->create(m_navTreeDock,
-		                 "komparenavtreepart", "KParts::ReadOnlyPart" ));
+		                 "KompareNavTreePart", QStringList("KParts::ReadOnlyPart" )));
 
 		if ( m_navTreePart )
 		{
 			m_navTreeDock->setWidget( m_navTreePart->widget() );
-			m_navTreeDock->manualDock( m_mainViewDock, KDockWidget::DockTop, 20 );
+			addDockWidget( Qt::TopDockWidgetArea, m_navTreeDock );
+// 			m_navTreeDock->manualDock( m_mainViewDock, KDockWidget::DockTop, 20 );
 		}
 	}
 	else
@@ -175,6 +185,9 @@ KompareShell::KompareShell()
 	connect( m_viewPart, SIGNAL( setStatusBarText(const QString&) ),
 	         this, SLOT( slotSetStatusBarText(const QString&) ) );
 
+	connect( m_viewPart, SIGNAL(diffString(const QString&)),
+	         this, SLOT(slotSetDiffString(const QString&)) );
+
 	// Read basic main-view settings, and set to autosave
 	setAutoSaveSettings( "General Options" );
 }
@@ -188,18 +201,18 @@ bool KompareShell::queryClose()
 	return m_viewPart->queryClose();
 }
 
-void KompareShell::openDiff(const KURL& url)
+void KompareShell::openDiff(const KUrl& url)
 {
-	kdDebug(8102) << "Url = " << url.prettyURL() << endl;
+	kDebug(8102) << "Url = " << url.prettyUrl() << endl;
 	m_diffURL = url;
 	m_viewPart->openDiff( url );
 }
 
 void KompareShell::openStdin()
 {
-	kdDebug(8102) << "Using stdin to read the diff" << endl;
+	kDebug(8102) << "Using stdin to read the diff" << endl;
 	QFile file;
-	file.open( IO_ReadOnly, stdin );
+	file.open( QIODevice::ReadOnly, stdin );
 	QTextStream stream( &file );
 
 	QString diff = stream.read();
@@ -210,7 +223,7 @@ void KompareShell::openStdin()
 
 }
 
-void KompareShell::compare(const KURL& source,const KURL& destination )
+void KompareShell::compare(const KUrl& source,const KUrl& destination )
 {
 	m_sourceURL = source;
 	m_destinationURL = destination;
@@ -218,7 +231,7 @@ void KompareShell::compare(const KURL& source,const KURL& destination )
 	m_viewPart->compare( source, destination );
 }
 
-void KompareShell::blend( const KURL& url1, const KURL& diff )
+void KompareShell::blend( const KUrl& url1, const KUrl& diff )
 {
 	m_sourceURL = url1;
 	m_destinationURL = diff;
@@ -228,56 +241,58 @@ void KompareShell::blend( const KURL& url1, const KURL& diff )
 
 void KompareShell::setupActions()
 {
-	KAction* open = KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
-	open->setText( i18n( "&Open Diff..." ) );
-	new KAction( i18n("&Compare Files..."), "fileopen", Qt::CTRL + Qt::Key_C,
-	              this, SLOT(slotFileCompareFiles()),
-	              actionCollection(), "file_compare_files" );
-	new KAction( i18n("&Blend URL with Diff..."), "fileblend", Qt::CTRL + Qt::Key_B,
-	              this, SLOT(slotFileBlendURLAndDiff()),
-	              actionCollection(), "file_blend_url" );
-	KStdAction::quit( this, SLOT( slotFileClose() ), actionCollection() );
+	KAction *a;
+	a = actionCollection()->addAction(KStandardAction::Open, this, SLOT(slotFileOpen()));
+	a->setText( i18n( "&Open Diff..." ) );
+	a = actionCollection()->addAction("file_compare_files", this, SLOT(slotFileCompareFiles()));
+	a->setIcon(KIcon("document-open"));
+	a->setText(i18n("&Compare Files..."));
+	a->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_C));
+	a = actionCollection()->addAction("file_blend_url", this, SLOT(slotFileBlendURLAndDiff()));
+	a->setText(i18n("&Blend URL with Diff..."));
+	a->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_B));
+	actionCollection()->addAction(KStandardAction::Quit, this, SLOT( slotFileClose() ));
 
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
 	createStandardStatusBarAction();
-#endif
 	setStandardToolBarMenuEnabled(true);
-	m_showTextView = new KToggleAction( i18n("Show T&ext View"), 0, this, SLOT(slotShowTextView()),
-	                                  actionCollection(), "options_show_text_view" );
-        m_showTextView->setCheckedState(i18n("Hide T&ext View"));
+	m_showTextView = new KToggleAction(i18n("Show T&ext View"), this);
+// needs a KGuiItem, also the doc says explicitly not to do this
+//	m_showTextView->setCheckedState(i18n("Hide T&ext View"));
+	actionCollection()->addAction("options_show_text_view", m_showTextView);
+	connect(m_showTextView, SIGNAL(triggered(bool)), SLOT(slotShowTextView()));
 
-	KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
-	KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
+	KStandardAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
+	KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
 }
 
 void KompareShell::setupStatusBar()
 {
 	// Made these entries permanent so they will appear on the right side
-	statusBar()->insertItem( i18n(" 0 of 0 differences "), ID_N_OF_N_DIFFERENCES, 0, true );
-	statusBar()->insertItem( i18n(" 0 of 0 files "), ID_N_OF_N_FILES, 0, true );
+	statusBar()->insertPermanentItem( i18n(" 0 of 0 differences "), ID_N_OF_N_DIFFERENCES, 0);
+	statusBar()->insertPermanentItem( i18n(" 0 of 0 files "), ID_N_OF_N_FILES, 0);
 
-	m_generalLabel = new KSqueezedTextLabel( "", 0, "general_statusbar_label" );
+	m_generalLabel = new KSqueezedTextLabel( "", 0 );
 	statusBar()->addWidget( m_generalLabel, 1, false );
 	m_generalLabel->setAlignment( Qt::AlignLeft );
 }
 
 void KompareShell::slotUpdateStatusBar( int modelIndex, int differenceIndex, int modelCount, int differenceCount, int appliedCount )
 {
-	kdDebug(8102) << "KompareShell::updateStatusBar()" << endl;
+	kDebug(8102) << "KompareShell::updateStatusBar()" << endl;
 
 	QString fileStr;
 	QString diffStr;
 
 	if ( modelIndex >= 0 )
-		fileStr = i18n( " %1 of %n file ", " %1 of %n files ", modelCount ).arg( modelIndex + 1 );
+		fileStr = i18np( " %2 of %1 file ", " %2 of %1 files ", modelCount, modelIndex + 1 );
 	else
-		fileStr = i18n( " %n file ", " %n files ", modelCount );
+		fileStr = i18np( " %1 file ", " %1 files ", modelCount );
 
 	if ( differenceIndex >= 0 )
-		diffStr = i18n( " %1 of %n difference, %2 applied ", " %1 of %n differences, %2 applied ", differenceCount )
-		          .arg( differenceIndex + 1 ).arg( appliedCount );
+		diffStr = i18np( " %2 of %1 difference, %3 applied ", " %2 of %1 differences, %3 applied ", differenceCount ,
+		            differenceIndex + 1, appliedCount );
 	else
-		diffStr = i18n( " %n difference ", " %n differences ", differenceCount );
+		diffStr = i18np( " %1 difference ", " %1 differences ", differenceCount );
 
 	statusBar()->changeItem( fileStr, ID_N_OF_N_FILES );
 	statusBar()->changeItem( diffStr, ID_N_OF_N_DIFFERENCES );
@@ -290,72 +305,72 @@ void KompareShell::slotSetStatusBarText( const QString& text )
 
 void KompareShell::setCaption( const QString& caption )
 {
-//	kdDebug() << kdBacktrace();
-	KParts::DockMainWindow::setCaption( caption, m_viewPart->isModified() );
+//	kDebug() << kBacktrace();
+	KParts::MainWindow::setCaption( caption, m_viewPart->isModified() );
 }
 
-void KompareShell::saveProperties(KConfig* config)
+void KompareShell::saveProperties(KConfigGroup &config)
 {
 	// The 'config' object points to the session managed
 	// config file.  Anything you write here will be available
 	// later when this app is restored
 	if ( m_mode == Kompare::ComparingFiles )
 	{
-		config->writeEntry( "Mode", "ComparingFiles" );
-		config->writePathEntry( "SourceUrl", m_sourceURL.url() );
-		config->writePathEntry( "DestinationUrl", m_destinationURL.url() );
+		config.writeEntry( "Mode", "ComparingFiles" );
+		config.writePathEntry( "SourceUrl", m_sourceURL.url() );
+		config.writePathEntry( "DestinationUrl", m_destinationURL.url() );
 	}
 	else if ( m_mode == Kompare::ShowingDiff )
 	{
-		config->writeEntry( "Mode", "ShowingDiff" );
-		config->writePathEntry( "DiffUrl", m_diffURL.url() );
+		config.writeEntry( "Mode", "ShowingDiff" );
+		config.writePathEntry( "DiffUrl", m_diffURL.url() );
 	}
 
-	m_viewPart->saveProperties( config );
+	m_viewPart->saveProperties( config.config() );
 }
 
-void KompareShell::readProperties(KConfig* config)
+void KompareShell::readProperties(const KConfigGroup &config)
 {
 	// The 'config' object points to the session managed
 	// config file. This function is automatically called whenever
 	// the app is being restored. Read in here whatever you wrote
 	// in 'saveProperties'
 
-	QString mode = config->readEntry( "Mode", "ComparingFiles" );
+	QString mode = config.readEntry( "Mode", "ComparingFiles" );
 	if ( mode == "ComparingFiles" )
 	{
 		m_mode  = Kompare::ComparingFiles;
-		m_sourceURL  = config->readPathEntry( "SourceUrl", "" );
-		m_destinationURL = config->readPathEntry( "DestinationFile", "" );
+		m_sourceURL  = config.readPathEntry( "SourceUrl", "" );
+		m_destinationURL = config.readPathEntry( "DestinationFile", "" );
 
-		m_viewPart->readProperties( config );
+		m_viewPart->readProperties( const_cast<KConfig *>(config.config()) );
 
 		m_viewPart->compareFiles( m_sourceURL, m_destinationURL );
 	}
 	else if ( mode == "ShowingDiff" )
 	{
 		m_mode = Kompare::ShowingDiff;
-		m_diffURL = config->readPathEntry( "DiffUrl", "" );
+		m_diffURL = config.readPathEntry( "DiffUrl", "" );
 
-		m_viewPart->readProperties( config );
+		m_viewPart->readProperties( const_cast<KConfig *>(config.config()) );
 
-		m_viewPart->openURL( m_diffURL );
+		m_viewPart->openUrl( m_diffURL );
 	}
 	else
-	{ // just in case something weird has happened, dont restore the diff then
+	{ // just in case something weird has happened, don't restore the diff then
 	  // Bruggie: or when some idiot like me changes the possible values for mode
 	  // IOW, a nice candidate for a kconf_update thingy :)
-		m_viewPart->readProperties( config );
+		m_viewPart->readProperties( const_cast<KConfig *>(config.config()) );
 	}
 }
 
 void KompareShell::slotFileOpen()
 {
 	// FIXME: use different filedialog which gets encoding
-	KURL url = KFileDialog::getOpenURL( QString::null, "text/x-diff", this );
+	KUrl url = KFileDialog::getOpenUrl( KUrl(), "text/x-patch", this );
 	if( !url.isEmpty() ) {
 		KompareShell* shell = new KompareShell();
-		kapp->ref();
+		KGlobal::ref();
 		shell->show();
 		shell->openDiff( url );
 	}
@@ -369,8 +384,8 @@ void KompareShell::slotFileBlendURLAndDiff()
 	dialog->setFirstGroupBoxTitle( i18n( "File/Folder" ) );
 	dialog->setSecondGroupBoxTitle( i18n( "Diff Output" ) );
 
-	KGuiItem blendGuiItem( i18n( "Blend" ), QString::null, i18n( "Blend this file or folder with the diff output" ), i18n( "If you have entered a file or folder name and a file that contains diff output in the fields in this dialog then this button will be enabled and pressing it will open kompare's main view where the output of the entered file or files from the folder are mixed with the diff output so you can then apply the difference(s) to a file or to the files. " ) );
-	dialog->setButtonOK( blendGuiItem );
+	KGuiItem blendGuiItem( i18n( "Blend" ), QString(), i18n( "Blend this file or folder with the diff output" ), i18n( "If you have entered a file or folder name and a file that contains diff output in the fields in this dialog then this button will be enabled and pressing it will open kompare's main view where the output of the entered file or files from the folder are mixed with the diff output so you can then apply the difference(s) to a file or to the files. " ) );
+	dialog->setButtonGuiItem( KDialog::Ok, blendGuiItem );
 
 	dialog->setGroup( "Recent Blend Files" );
 
@@ -382,7 +397,7 @@ void KompareShell::slotFileBlendURLAndDiff()
 		m_sourceURL = dialog->getFirstURL();
 		m_destinationURL = dialog->getSecondURL();
 		KompareShell* shell = new KompareShell();
-		kapp->ref();
+		KGlobal::ref();
 		shell->show();
 		shell->m_viewPart->setEncoding( dialog->encoding() );
 		shell->blend( m_sourceURL, m_destinationURL );
@@ -398,8 +413,8 @@ void KompareShell::slotFileCompareFiles()
 	dialog->setFirstGroupBoxTitle( i18n( "Source" ) );
 	dialog->setSecondGroupBoxTitle( i18n( "Destination" ) );
 
-	KGuiItem compareGuiItem( i18n( "Compare" ), QString::null, i18n( "Compare these files or folders" ), i18n( "If you have entered 2 filenames or 2 folders in the fields in this dialog then this button will be enabled and pressing it will start a comparison of the entered files or folders. " ) );
-	dialog->setButtonOK( compareGuiItem );
+	KGuiItem compareGuiItem( i18n( "Compare" ), QString(), i18n( "Compare these files or folders" ), i18n( "If you have entered 2 filenames or 2 folders in the fields in this dialog then this button will be enabled and pressing it will start a comparison of the entered files or folders. " ) );
+	dialog->setButtonGuiItem( KDialog::Ok, compareGuiItem );
 
 	dialog->setGroup( "Recent Compare Files" );
 
@@ -411,9 +426,9 @@ void KompareShell::slotFileCompareFiles()
 		m_sourceURL = dialog->getFirstURL();
 		m_destinationURL = dialog->getSecondURL();
 		KompareShell* shell = new KompareShell();
-		kapp->ref();
+		KGlobal::ref();
 		shell->show();
-		kdDebug() << "Damn it, i should be called !!! Oh and encoding is: " << dialog->encoding() << endl;
+		kDebug() << "Damn it, i should be called !!! Oh and encoding is: " << dialog->encoding() << endl;
 		shell->m_viewPart->setEncoding( dialog->encoding() );
 		shell->compare( m_sourceURL, m_destinationURL );
 	}
@@ -425,7 +440,7 @@ void KompareShell::slotFileClose()
 	if ( m_viewPart->queryClose() )
 	{
 		delete this;
-		kapp->deref();
+		KGlobal::deref();
 	}
 }
 
@@ -436,52 +451,68 @@ void KompareShell::slotShowTextView()
 		int errCode;
 
 		// FIXME: proper error checking
-		m_textViewWidget = createDockWidget( i18n("Text View"), SmallIcon( "text") );
-		m_textViewPart = KParts::ComponentFactory::createPartInstanceFromQuery<KTextEditor::Document>(
+		m_textViewWidget = new QDockWidget( i18n( "Text View" ), this );
+		m_textViewWidget->setObjectName( "Text View" );
+// 		m_textViewWidget = createDockWidget( i18n("Text View"), SmallIcon( "text-x-generic") );
+		m_textViewPart = KServiceTypeTrader::createInstanceFromQuery<KTextEditor::Document>(
 		                 QString::fromLatin1("KTextEditor/Document"),
-		                 QString::null, (QWidget*)this, 0, (QWidget*)this, 0, QStringList(), &errCode );
+		                 QString(), (QWidget*)this, QStringList(), &errCode );
 		if ( m_textViewPart )
 		{
-			m_textView = m_textViewPart->createView( this, 0 );
+			m_textView = qobject_cast<KTextEditor::View*>( m_textViewPart->createView( this ) );
 			m_textViewWidget->setWidget( static_cast<QWidget*>(m_textView) );
-			m_textEditIface = editInterface( m_textViewPart );
-			connect( m_viewPart, SIGNAL(diffString(const QString&)),
-			         this, SLOT(slotSetDiffString(const QString&)) );
+	 		m_textViewPart->setHighlightingMode( "Diff" );
+	 		m_textViewPart->setText( m_diffString );
 		}
+		m_textViewWidget->show();
+		connect( m_textViewWidget, SIGNAL(visibilityChanged(bool)), SLOT(slotVisibilityChanged(bool)) );
 	}
+	else if ( m_textViewWidget->isVisible() )
+		m_textViewWidget->hide();
+	else
+		m_textViewWidget->show();
 
-	m_textViewWidget->manualDock( m_mainViewDock, KDockWidget:: DockCenter );
+	addDockWidget( Qt::BottomDockWidgetArea, m_textViewWidget );
+// 	m_textViewWidget->manualDock( m_mainViewDock, KDockWidget:: DockCenter );
+}
+
+void KompareShell::slotVisibilityChanged( bool visible )
+{
+	m_showTextView->setChecked( visible );
 }
 
 void KompareShell::slotSetDiffString( const QString& diffString )
 {
-	if ( m_textEditIface )
-		m_textEditIface->setText( diffString );
+ 	if ( m_textViewPart )
+ 		m_textViewPart->setText( diffString );
+	m_diffString = diffString;
 }
 
 void KompareShell::optionsConfigureKeys()
 {
-	KKeyDialog dlg( true, this );
+	KShortcutsDialog dlg( KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this );
 
-	dlg.insert( actionCollection() );
+	dlg.addCollection( actionCollection() );
 	if ( m_viewPart )
-		dlg.insert( m_viewPart->actionCollection() );
+		dlg.addCollection( m_viewPart->actionCollection() );
 
 	dlg.configure();
 }
 
 void KompareShell::optionsConfigureToolbars()
 {
-	saveMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+	KConfigGroup group(KGlobal::config(), autoSaveGroup());
+	saveMainWindowSettings(group);
 	// use the standard toolbar editor
-	KEditToolbar dlg(factory());
+	KEditToolBar dlg(factory());
 	connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(newToolbarConfig()));
 	dlg.exec();
 }
 
 void KompareShell::newToolbarConfig()
 {
-	applyMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+	KConfigGroup group(KGlobal::config(), autoSaveGroup());
+	applyMainWindowSettings(group);
 }
 
 #include "kompare_shell.moc"
