@@ -1,11 +1,9 @@
 /***************************************************************************
-                                difference.cpp  -  description
-                                -------------------
+                                difference.cpp
+                                --------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2003 by Otto Bruggeman
-                                  and John Firebaugh
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
+        Copyright 2001-2003 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
 ****************************************************************************/
 
 /***************************************************************************
@@ -78,7 +76,7 @@ void Difference::determineInlineDifferences()
 		DifferenceString* sl = sourceLineAt( i );
 		DifferenceString* dl = destinationLineAt( i );
 
-		// FIXME: If the table cant be created dont do the rest
+		// FIXME: If the table cannot be created do not do the rest
 		table.createTable( sl, dl );
 
 		table.createListsOfMarkers();
@@ -99,13 +97,13 @@ QString Difference::recreateDifference() const
 		{
 		case Change:
 		case Delete:
-			difference += "-";
+			difference += '-';
 			break;
 		default:
 		// Insert but this is not possible in source
 		// Unchanged will be handled in destination
 		// since they are the same
-//			kdDebug( 8101 ) << "Go away, nothing to do for you in source..." << endl;
+//			kDebug( 8101 ) << "Go away, nothing to do for you in source..." << endl;
 			continue;
 		}
 		difference += (*stringIt)->string();
@@ -121,13 +119,13 @@ QString Difference::recreateDifference() const
 		{
 		case Change:
 		case Insert:
-			difference += "+";
+			difference += '+';
 			break;
 		case Unchanged:
-			difference += " ";
+			difference += ' ';
 			break;
 		default: // Delete but this is not possible in destination
-//			kdDebug( 8101 ) << "Go away, nothing to do for you in destination..." << endl;
+//			kDebug( 8101 ) << "Go away, nothing to do for you in destination..." << endl;
 			continue;
 		}
 		difference += (*stringIt)->string();
