@@ -15,10 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qobjectdict.h>
-#include <qobjectlist.h>
+#include <q3objectdict.h>
+#include <qobject.h>
 #include <qmetaobject.h>
-#include <qstrlist.h>
+#include <q3strlist.h>
 #include <qvariant.h>
 #include <qcursor.h>
 
@@ -26,11 +26,11 @@
 
 #include "propsview.h"
 
-class KSpyItem : KListViewItem 
+class KSpyItem : K3ListViewItem 
 {
 public:
-  KSpyItem( QListView * parent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null )  
-    : KListViewItem(parent, label1, label2, label3, label4, label5, label6)
+  KSpyItem( Q3ListView * parent, QString label1, QString label2 = QString(), QString label3 = QString(), QString label4 = QString(), QString label5 = QString(), QString label6 = QString() )
+    : K3ListViewItem(parent, label1, label2, label3, label4, label5, label6)
   {
   }
 protected:
@@ -41,14 +41,15 @@ protected:
       QColorGroup color_cg( cg.foreground(), cg.background(), 
                             cg.light(), cg.dark(), cg.mid(), 
                             QColor(text(1)), QColor(text(1)) );
-      QListViewItem::paintCell(p, color_cg, column, width, alignment);
+      Q3ListViewItem::paintCell(p, color_cg, column, width, alignment);
     } else {
-      KListViewItem::paintCell(p, cg, column, width, alignment);
+      K3ListViewItem::paintCell(p, cg, column, width, alignment);
     }
   }
 };
 
-PropsView::PropsView(QWidget *parent, const char *name ) : KListView(parent,name)
+PropsView::PropsView(QWidget *parent, const char *name ) 
+	: K3ListView(parent)
 {
   addColumn( i18n( "Name" ) );
   addColumn( i18n( "Value" ) );
@@ -58,8 +59,8 @@ PropsView::PropsView(QWidget *parent, const char *name ) : KListView(parent,name
   addColumn( i18n( "Type Flags" ) );
 
   setAllColumnsShowFocus( true );
-  setColumnAlignment( 3, AlignCenter );
-  setColumnAlignment( 4, AlignCenter );
+  setColumnAlignment( 3, Qt::AlignCenter );
+  setColumnAlignment( 4, Qt::AlignCenter );
   setFullWidth( true );
 }
 
@@ -70,7 +71,7 @@ PropsView::~PropsView()
 void PropsView::buildList( QObject *o )
 {
   QMetaObject *mo = o->metaObject();
-  QStrList names = mo->propertyNames( true );
+  Q3StrList names = mo->propertyNames( true );
 
   for ( uint i = 0; i < names.count(); i++ ) {
     char *prop = names.at( i );
@@ -88,8 +89,7 @@ void PropsView::buildList( QObject *o )
          break;
        case QVariant::Color:
        {
-         QColor c = v.toColor();
-         val = c.name();
+         val = v.toString();
          break;
        }
        case QVariant::Cursor:
@@ -161,8 +161,8 @@ void PropsView::buildList( QObject *o )
     QString no("No");
 
     QString writable = ( mp->writable() ? rw : ro );
-    QString setType = ( mp->isSetType() ? st : QString::null );
-    QString enumType = ( mp->isEnumType() ? et : QString::null );
+    QString setType = ( mp->isSetType() ? st : QString() );
+    QString enumType = ( mp->isEnumType() ? et : QString() );
     QString designable = ( mp->designable(o) ? yes : no );
 
     QString flags;
