@@ -41,7 +41,7 @@ public:
      * @param useFolders If the tree structure of the views in the document must be created
      *                   in the target directory.
      */
-    CmdLineExportAllViewsEvent(const QString &imageType, const KURL &directory, const bool useFolders);
+    CmdLineExportAllViewsEvent(const QString &imageType, const KUrl &directory, const bool useFolders);
 
     /**
      * Destructor for CmdLineExportAllViewsEvent
@@ -66,7 +66,7 @@ private:
     /**
      * The url of the directory where the images will be saved.
      */
-    KURL m_directory;
+    KUrl m_directory;
 
     /**
      * If the tree structure of the views in the document must be created
