@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2007                                                    *
+ *   copyright (C) 2007-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -15,17 +15,17 @@
 #include "csharpwriter.h"
 
 #include <kdebug.h>
-#include <qregexp.h>
-#include <qtextstream.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QTextStream>
 
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../folder.h"
-#include "../classifier.h"
-#include "../association.h"
-#include "../attribute.h"
-#include "../operation.h"
-#include "../umlnamespace.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "folder.h"
+#include "classifier.h"
+#include "association.h"
+#include "attribute.h"
+#include "operation.h"
+#include "umlnamespace.h"
 
 static const char *reserved_words[] = {
     "abstract",
@@ -116,7 +116,8 @@ CSharpWriter::~CSharpWriter()
 {
 }
 
-QStringList CSharpWriter::defaultDatatypes() {
+QStringList CSharpWriter::defaultDatatypes()
+{
     QStringList l;
     l.append("bool");
     l.append("byte");
@@ -139,9 +140,10 @@ QStringList CSharpWriter::defaultDatatypes() {
     return l;
 }
 
-void CSharpWriter::writeClass(UMLClassifier *c) {
+void CSharpWriter::writeClass(UMLClassifier *c)
+{
     if (!c) {
-        kDebug()<<"Cannot write class of NULL concept!" << endl;
+        uDebug()<<"Cannot write class of NULL concept!";
         return;
     }
 
@@ -164,13 +166,12 @@ void CSharpWriter::writeClass(UMLClassifier *c) {
     //Start generating the code!!
     /////////////////////////////
 
-
     //try to find a heading file (license, coments, etc)
     QString str;
     str = getHeadingFile(".cs");
     if (!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),fileName);
-        str.replace(QRegExp("%filepath%"),filecs.name());
+        str.replace(QRegExp("%filepath%"),filecs.fileName());
         cs<<str<<m_endl;
     }
 
@@ -194,12 +195,12 @@ void CSharpWriter::writeClass(UMLClassifier *c) {
     m_seenIncludes.clear();
     //m_seenIncludes.append(logicalView);
     if (includes.count()) {
-        UMLPackage *p;
-        for (UMLPackageListIt it(includes); (p = it.current()) != NULL; ++it) {
+
+        foreach ( UMLPackage* p , includes ) {
             UMLClassifier *cl = dynamic_cast<UMLClassifier*>(p);
             if (cl)
                 p = cl->getUMLPackage();
-            if (p != logicalView && m_seenIncludes.findRef(p) == -1 && p != container) {
+            if (p != logicalView && m_seenIncludes.indexOf(p) == -1 && p != container) {
                 cs << "using " << p->getFullyQualifiedName(".") << ";" << m_endl;
                 m_seenIncludes.append(p);
             }
@@ -244,9 +245,8 @@ void CSharpWriter::writeClass(UMLClassifier *c) {
 
         // write baseclass, ignore interfaces, write error on multiple inheritance
         if (superclasses.count() > 0) {
-            UMLClassifier *obj;
             int supers = 0;
-            for (obj = superclasses.first(); obj; obj = superclasses.next()) {
+            foreach (UMLClassifier* obj, superclasses ) {
                 if (!obj->isInterface()) {
                     if (supers > 0) {
                         cs << " // AND ";
@@ -261,10 +261,9 @@ void CSharpWriter::writeClass(UMLClassifier *c) {
         }
         //check for realizations
         UMLAssociationList realizations = c->getRealizations();
-        UMLAssociation *a;
 
         if (!realizations.isEmpty()) {
-            for (a = realizations.first(); a; a = realizations.next()) {
+            foreach (UMLAssociation* a , realizations ) {
                 UMLClassifier *real = (UMLClassifier*)a->getObject(Uml::B);
                 if(real != c) {
                     // write list of realizations
@@ -314,21 +313,17 @@ void CSharpWriter::writeClass(UMLClassifier *c) {
 ////////////////////////////////////////////////////////////////////////////////////
 //  Helper Methods
 
-void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs) {
-
+void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
+{
     //Lists to store operations  sorted by scope
     UMLOperationList oppub,opprot,oppriv;
 
     bool isInterface = c->isInterface();
     bool generateErrorStub = true;
 
-    oppub.setAutoDelete(false);
-    opprot.setAutoDelete(false);
-    oppriv.setAutoDelete(false);
-
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
-    for (UMLOperation *op = opl.first(); op ; op = opl.next()) {
+    foreach (UMLOperation* op,  opl ) {
         switch (op->getVisibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -382,17 +377,16 @@ void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs) {
 
 }
 
-void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTextStream &cs) {
+void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTextStream &cs)
+{
     // oplist for implemented abstract operations
     UMLOperationList opabstract;
-    opabstract.setAutoDelete(false);
-    UMLClassifier *obj;
 
-    for (obj = superclasses->first(); obj; obj = superclasses->next()) {
+    foreach (UMLClassifier* obj, *superclasses ) {
         if (!obj->isInterface() && obj->hasAbstractOps()) {
             // collect abstract ops
             UMLOperationList opl(obj->getOpList());
-            for (UMLOperation *op = opl.first(); op ; op = opl.next()) {
+            foreach (UMLOperation* op, opl ) {
                 if (op->getAbstract()) {
                     opabstract.append(op);
                 }
@@ -413,10 +407,11 @@ void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTex
         }
     }
 }
-void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAssociationList *realizations, QTextStream &cs) {
 
-    UMLAssociation *a;
-    for (a = realizations->first(); a; a = realizations->next()) {
+void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAssociationList *realizations, QTextStream &cs)
+{
+    for (UMLAssociationListIt alit(*realizations); alit.hasNext(); ) {
+        UMLAssociation *a = alit.next();
 
         // we know its a classifier if its in the list
         UMLClassifier *real = (UMLClassifier*)a->getObject(Uml::B);
@@ -444,16 +439,15 @@ void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAs
 void CSharpWriter::writeOperations(UMLOperationList opList,
                                  QTextStream &cs, bool isInterface /* = false */,
                                  bool isOverride /* = false */,
-                                 bool generateErrorStub /* = false */) {
-
-    for (UMLOperation *op=opList.first(); op ; op=opList.next()) {
+                                 bool generateErrorStub /* = false */)
+{
+    foreach (UMLOperation* op, opList ) {
         UMLAttributeList atl = op->getParmList();
-        UMLAttribute *at;
 
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
 
-        for (at = atl.first(); at; at = atl.next()) {
+        foreach ( UMLAttribute* at, atl ) {
             writeDoc |= !at->getDoc().isEmpty();
         }
 
@@ -465,12 +459,11 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
             cs << m_container_indent << m_indentation << "/// </summary>" << m_endl;
 
             //write parameter documentation
-            for (at = atl.first(); at; at = atl.next())
-            {
+            foreach ( UMLAttribute* at, atl ) {
                 if (forceDoc() || !at->getDoc().isEmpty()) {
                     cs << m_container_indent << m_indentation << "/// <param name=\"" << cleanName(at->getName()) << "\">";
                     //removing newlines from parameter doc
-                    cs << formatDoc(at->getDoc(), "").replace("\n", " ").remove('\r').replace(QRegExp(" $"), "");
+                    cs << formatDoc(at->getDoc(), "").replace("\n", " ").remove('\r').remove(QRegExp(" $"));
                     cs << "</param>" << m_endl;
                 }
             }
@@ -515,8 +508,8 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         // method parameters
         int i= atl.count();
         int j=0;
-        for (at = atl.first(); at; at = atl.next(), j++) {
-
+        for (UMLAttributeListIt atlIt( atl ); atlIt.hasNext() ; j++) {
+            UMLAttribute* at = atlIt.next();
             cs << makeLocalTypeName(at) << " " << cleanName(at->getName());
 
             // no initial values in C#
@@ -530,9 +523,16 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         //FIXME: how to control generation of error stub?
         if (!isInterface && (!op->getAbstract() || isOverride)) {
             cs << m_endl << m_container_indent << m_indentation << "{" << m_endl;
-            if (generateErrorStub) {
-                cs << m_container_indent << m_indentation << m_indentation;
-                cs << "throw new Exception(\"The method or operation is not implemented.\");" << m_endl;
+            // write source code of operation else throw not implemented exception
+            QString sourceCode = op->getSourceCode();
+            if (sourceCode.isEmpty()) {
+                if (generateErrorStub) {
+                    cs << m_container_indent << m_indentation << m_indentation;
+                    cs << "throw new Exception(\"The method or operation is not implemented.\");" << m_endl;
+                }
+            }
+            else {
+                cs << formatSourceCode(sourceCode, m_container_indent + m_indentation + m_indentation);
             }
             cs << m_container_indent << m_indentation << "}" << m_endl;
         }
@@ -543,19 +543,14 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
     }
 }
 
-void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs) {
-
+void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
+{
     UMLAttributeList  atpub, atprot, atpriv, atdefval;
-    atpub.setAutoDelete(false);
-    atprot.setAutoDelete(false);
-    atpriv.setAutoDelete(false);
-    atdefval.setAutoDelete(false);
 
     //sort attributes by scope and see if they have a default value
     UMLAttributeList atl = c->getAttributeList();
-    UMLAttribute *at;
 
-    for (at = atl.first(); at ; at = atl.next()) {
+    foreach ( UMLAttribute* at, atl ) {
         if (!at->getInitialValue().isEmpty())
             atdefval.append(at);
         switch (at->getVisibility()) {
@@ -596,10 +591,9 @@ void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs) {
 
 }
 
-
-void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs) {
-
-    for (UMLAttribute *at = atList.first(); at ; at = atList.next()) {
+void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs)
+{
+    foreach (UMLAttribute* at, atList ) {
 
         bool asProperty = true;
         if (at->getVisibility() == Uml::Visibility::Private) {
@@ -613,16 +607,15 @@ void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs) {
     return;
 }
 
-void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLClassifier *c, QTextStream &cs) {
-
-    UMLAssociation *a;
-    for (a = associated.first(); a ; a = associated.next()) {
+void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLClassifier *c, QTextStream &cs)
+{
+    foreach (UMLAssociation *a,  associated ) {
         if (c != a->getObject(Uml::A))  // we need to be at the A side
             continue;
 
         UMLObject *o = a->getObject(Uml::B);
         if (o == NULL) {
-            kError() << "composition role B object is NULL" << endl;
+            uError() << "composition role B object is NULL" << endl;
             continue;
         }
         // Take name and documentaton from Role, take type name from the referenced object
@@ -645,8 +638,15 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
     }
 }
 
-void CSharpWriter::writeAttribute(QString doc, Uml::Visibility visibility, bool isStatic, QString typeName, QString name, QString initialValue, bool asProperty, QTextStream &cs) {
-
+void CSharpWriter::writeAttribute(const QString& doc,
+                                  Uml::Visibility visibility,
+                                  bool isStatic,
+                                  const QString& typeName,
+                                  const QString& name,
+                                  const QString& initialValue,
+                                  bool asProperty,
+                                  QTextStream &cs)
+{
     if (forceDoc() || !doc.isEmpty()) {
 
         cs << m_container_indent << m_indentation << "/// <summary>" << m_endl;
@@ -691,9 +691,10 @@ void CSharpWriter::writeAttribute(QString doc, Uml::Visibility visibility, bool
     cs << ";" << m_endl << m_endl;
 }
 
-QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl) {
+QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl)
+{
     UMLPackage *p = cl->getType()->getUMLPackage();
-    if (m_seenIncludes.findRef(p) != -1) {
+    if (m_seenIncludes.indexOf(p) != -1) {
         return cl->getType()->getName();
     }
     else {
@@ -705,12 +706,13 @@ QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl) {
 /**
  * returns "C#"
  */
-Uml::Programming_Language CSharpWriter::getLanguage() {
+Uml::Programming_Language CSharpWriter::getLanguage()
+{
     return Uml::pl_CSharp;
 }
 
-const QStringList CSharpWriter::reservedKeywords() const {
-
+const QStringList CSharpWriter::reservedKeywords() const
+{
     static QStringList keywords;
 
     if (keywords.isEmpty()) {
