@@ -1,7 +1,7 @@
 /***************************************************************************
     begin                : Wed Jan 22 2003
     copyright            : (C) 2003 by David Hugh-Jones
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
+      (C) 2004-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
     email                : hughjonesd@yahoo.co.uk
  ***************************************************************************/
 
@@ -33,22 +33,24 @@ PerlWriter::PerlWriter()
 {
 }
 
-PerlWriter::~PerlWriter() {}
+PerlWriter::~PerlWriter()
+{
+}
 
 bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
-                                  QString &ThisPkgName){
-
-  if(!c){
+                                  QString &ThisPkgName)
+{
+  if (!c){
     return(false);
   }
 
   UMLPackageList includes;
   findObjectsRelated(c,includes);
-  UMLPackage *conc;
+
   QString AV = "@";
   QString SV = "$";
   QString HV = "%";
-  for(conc = includes.first(); conc ;conc = includes.next()) {
+  foreach (UMLPackage* conc, includes ) {
     if (conc->getBaseType() == Uml::ot_Datatype)
         continue;
     QString neatName = cleanName(conc->getName());
@@ -60,7 +62,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
       // Only print out the use statement if the other package isn't the
       // same as the one we are working on. (This happens for the
       // "Singleton" design pattern.)
-      if(OtherName != ThisPkgName){
+      if (OtherName != ThisPkgName){
         Ret += "use ";
         Ret += OtherName;
         Ret +=  ';';
@@ -72,8 +74,7 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
   if (superclasses.count()) {
     Ret += m_endl;
     Ret += "use base qw( ";
-    for (UMLClassifier *obj = superclasses.first();
-         obj; obj = superclasses.next()) {
+    foreach (UMLClassifier *obj , superclasses ) {
       QString packageName =  obj->getPackage(".");
       packageName.replace(QRegExp("\\."),"::");
 
@@ -85,10 +86,10 @@ bool PerlWriter::GetUseStatements(UMLClassifier *c, QString &Ret,
   return(true);
 }
 
-void PerlWriter::writeClass(UMLClassifier *c) {
-
-  /*  if(!c) {
-      kDebug()<<"Cannot write class of NULL concept!" << endl;
+void PerlWriter::writeClass(UMLClassifier *c)
+{
+  /*  if (!c) {
+      uDebug()<<"Cannot write class of NULL concept!";
       return;
       }
   */
@@ -97,7 +98,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   QString fileName;
 
   // Replace all white spaces with blanks
-  packageName.simplifyWhiteSpace();
+  packageName.simplified();
 
   // Replace all blanks with underscore
   packageName.replace(QRegExp(" "), "_");
@@ -117,7 +118,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   // actual solution: shameful ".pm" hack in codegenerator
 
   CodeGenerationPolicy *pol = UMLApp::app()->getCommonPolicy();
-  QString curDir = pol->getOutputDirectory().absPath();
+  QString curDir = pol->getOutputDirectory().absolutePath();
   if (fileName.contains("::")) {
     // create new directories for each level
     QString newDir;
@@ -126,7 +127,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     QDir* existing = new QDir (curDir);
     QRegExp regEx("(.*)(::)");
     regEx.setMinimal(true);
-    while (regEx.search(fragment) > -1) {
+    while (regEx.indexIn(fragment) > -1) {
       newDir = regEx.cap(1);
       fragment.remove(0, (regEx.pos(2) + 2)); // get round strange minimal matching bug
       existing->setPath(curDir + '/' + newDir);
@@ -145,10 +146,10 @@ void PerlWriter::writeClass(UMLClassifier *c) {
     emit codeGenerated(c, false);
     return;
   }
-  QString oldDir = pol->getOutputDirectory().absPath();
+  QString oldDir = pol->getOutputDirectory().absolutePath();
   pol->setOutputDirectory(curDir);
   QFile fileperl;
-  if(!openFile(fileperl, fileName)) {
+  if (!openFile(fileperl, fileName)) {
     emit codeGenerated(c, false);
     return;
   }
@@ -165,14 +166,14 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   bool bUseStmsWritten  = false;
 
   str = getHeadingFile(".pm");   // what this mean?
-  if(!str.isEmpty()) {
+  if (!str.isEmpty()) {
     str.replace(QRegExp("%filename%"),fileName);
-    str.replace(QRegExp("%filepath%"),fileperl.name());
+    str.replace(QRegExp("%filepath%"),fileperl.fileName());
     str.replace(QRegExp("%year%"),QDate::currentDate().toString("yyyy"));
     str.replace(QRegExp("%date%"),QDate::currentDate().toString());
     str.replace(QRegExp("%time%"),QTime::currentTime().toString());
     str.replace(QRegExp("%package-name%"),ThisPkgName);
-    if(str.find(QRegExp("%PACKAGE-DECLARE%"))){
+    if(str.indexOf(QRegExp("%PACKAGE-DECLARE%"))){
       str.replace(QRegExp("%PACKAGE-DECLARE%"),
                   "package " + ThisPkgName + ';'
                   + m_endl + m_endl
@@ -184,7 +185,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
       bPackageDeclared = true;
     }
 
-    if(str.find(QRegExp("%USE-STATEMENTS%"))){
+    if (str.indexOf(QRegExp("%USE-STATEMENTS%"))){
       QString UseStms;
       if(GetUseStatements(c,UseStms,ThisPkgName)){
         str.replace(QRegExp("%USE-STATEMENTS%"), UseStms);
@@ -197,7 +198,7 @@ void PerlWriter::writeClass(UMLClassifier *c) {
 
   // if the package wasn't declared above during keyword substitution,
   // add it now. (At the end of the file.)
-  if(! bPackageDeclared){
+  if (! bPackageDeclared){
     perl << m_endl << m_endl << "package " <<ThisPkgName << ";" << m_endl
          << m_endl;
     //write includes
@@ -207,9 +208,9 @@ void PerlWriter::writeClass(UMLClassifier *c) {
          << m_endl << m_endl ;
   }
 
-  if(! bUseStmsWritten){
+  if (! bUseStmsWritten){
     QString UseStms;
-    if(GetUseStatements(c,UseStms,ThisPkgName)){
+    if (GetUseStatements(c,UseStms,ThisPkgName)){
       perl<<UseStms<<m_endl;
     }
   }
@@ -221,15 +222,15 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   UMLAssociationList compositions = c->getCompositions();
 
     //Write class Documentation
-  if(forceDoc() || !c->getDoc().isEmpty()) {
+  if (forceDoc() || !c->getDoc().isEmpty()) {
     perl << m_endl << "=head1";
-    perl << " " << classname.upper() << m_endl << m_endl;
+    perl << " " << classname.toUpper() << m_endl << m_endl;
     perl << c->getDoc();
     perl << m_endl << m_endl << "=cut" << m_endl << m_endl;
   }
 
   //check if class is abstract and / or has abstract methods
-  if(c->getAbstract())
+  if (c->getAbstract())
     perl << "=head1 ABSTRACT CLASS" << m_endl << m_endl << "=cut" << m_endl;
 
   //attributes
@@ -250,29 +251,23 @@ void PerlWriter::writeClass(UMLClassifier *c) {
   emit codeGenerated(c, true);
 }
 
-/**
- * returns "Perl"
- */
-Uml::Programming_Language PerlWriter::getLanguage() {
+Uml::Programming_Language PerlWriter::getLanguage()
+{
     return Uml::pl_Perl;
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
 //  Helper Methods
 
-void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl) {
-
+void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl)
+{
     //Lists to store operations  sorted by scope
     UMLOperationList oppub,opprot,oppriv;
 
-    oppub.setAutoDelete(false);
-    opprot.setAutoDelete(false);
-    oppriv.setAutoDelete(false);
-
     //sort operations by scope first and see if there are abstract methods
     //keep this for documentation only!
     UMLOperationList opl(c->getOpList());
-    for(UMLOperation *op = opl.first(); op ; op = opl.next()) {
+    foreach (UMLOperation *op , opl ) {
         switch(op->getVisibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -291,20 +286,20 @@ void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl) {
     QString classname(cleanName(c->getName()));
 
     //write operations to file
-    if(forceSections() || !oppub.isEmpty()) {
+    if (forceSections() || !oppub.isEmpty()) {
         perl << m_endl << "=head1 PUBLIC METHODS" << m_endl << m_endl ;
         writeOperations(classname,oppub,perl);
         perl << m_endl << m_endl << "=cut" << m_endl << m_endl;
     }
 
-    if(forceSections() || !opprot.isEmpty()) {
+    if (forceSections() || !opprot.isEmpty()) {
         perl << m_endl << "=head1 METHODS FOR SUBCLASSING" << m_endl << m_endl ;
         //perl << "=pod "  << m_endl << m_endl << "=head3 " ;
         writeOperations(classname,opprot,perl);
         perl << m_endl << m_endl << "=cut" << m_endl << m_endl;
     }
 
-    if(forceSections() || !oppriv.isEmpty()) {
+    if (forceSections() || !oppriv.isEmpty()) {
         perl << m_endl << "=head1 PRIVATE METHODS" << m_endl << m_endl ;
         //perl << "=pod "  << m_endl << m_endl << "=head3 " ;
         writeOperations(classname,oppriv,perl);
@@ -320,8 +315,8 @@ void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl) {
         perl << "_init sets all " + classname + " attributes to their default values unless already set" << m_endl << m_endl << "=cut" << m_endl << m_endl;
         perl << "sub _init {" << m_endl << m_indentation << "my $self = shift;" << m_endl<<m_endl;
 
-        for(UMLAttribute *at = atl.first(); at ; at = atl.next()) {
-            if(!at->getInitialValue().isEmpty())
+        foreach (UMLAttribute *at , atl ) {
+            if (!at->getInitialValue().isEmpty())
                 perl << m_indentation << "defined $self->{" << cleanName(at->getName())<<"}"
                 << " or $self->{" << cleanName(at->getName()) << "} = "
                 << at->getInitialValue() << ";" << m_endl;
@@ -333,27 +328,24 @@ void PerlWriter::writeOperations(UMLClassifier *c, QTextStream &perl) {
     perl << m_endl << m_endl;
 }
 
-void PerlWriter::writeOperations(const QString &/* classname */, UMLOperationList &opList, QTextStream &perl) {
-    UMLOperation *op;
-    UMLAttribute *at;
-
-    for(op=opList.first(); op ; op=opList.next())
-    {
+void PerlWriter::writeOperations(const QString &/* classname */, UMLOperationList &opList, QTextStream &perl)
+{
+    foreach (UMLOperation* op , opList ) {
         UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for (at = atl.first(); at ; at = atl.next())
+        foreach (UMLAttribute* at , atl )
             writeDoc |= !at->getDoc().isEmpty();
 
-        if( writeDoc )  //write method documentation
+        if ( writeDoc )  //write method documentation
         {
             perl << "=pod "  << m_endl << m_endl << "=head3 " ;
             perl << cleanName(op->getName()) << m_endl << m_endl;
 
             perl << "   Parameters :" << m_endl ;
           //write parameter documentation
-          for (at = atl.first(); at ; at = atl.next()) {
-            if(forceDoc() || !at->getDoc().isEmpty()) {
+          foreach (UMLAttribute* at , atl ) {
+            if (forceDoc() || !at->getDoc().isEmpty()) {
               perl << "      "
                    << cleanName(at->getName()) << " : "
                    << at->getTypeName() << " : "
@@ -376,7 +368,7 @@ void PerlWriter::writeOperations(const QString &/* classname */, UMLOperationLis
 
         bool bStartPrinted = false;
         //write parameters
-        for (at = atl.first(); at; at = atl.next()) {
+        foreach (UMLAttribute* at , atl ) {
           if (!bStartPrinted) {
               bStartPrinted = true;
               perl << "," << m_endl;
@@ -387,26 +379,27 @@ void PerlWriter::writeOperations(const QString &/* classname */, UMLOperationLis
 
         perl << "    ) = @_;" << m_endl;
 
-        perl << "#UML_MODELER_BEGIN_PERSONAL_CODE_" << cleanName(op->getName());
-        perl << m_endl << "#UML_MODELER_END_PERSONAL_CODE_" << cleanName(op->getName()) << m_endl;
+        perl << "#UML_MODELER_BEGIN_PERSONAL_CODE_" << cleanName(op->getName()) << m_endl;
+        QString sourceCode = op->getSourceCode();
+        if (!sourceCode.isEmpty()) {
+            perl << formatSourceCode(sourceCode, m_indentation);
+        }
+        perl << "#UML_MODELER_END_PERSONAL_CODE_" << cleanName(op->getName()) << m_endl;
         perl << "}" << m_endl;
         perl << m_endl << m_endl;
     }//end for
 }
 
 
-void PerlWriter::writeAttributes(UMLClassifier *c, QTextStream &perl) {
+void PerlWriter::writeAttributes(UMLClassifier *c, QTextStream &perl)
+{
     UMLAttributeList  atpub, atprot, atpriv, atdefval;
-    atpub.setAutoDelete(false);
-    atprot.setAutoDelete(false);
-    atpriv.setAutoDelete(false);
-    atdefval.setAutoDelete(false);
 
     //sort attributes by scope and see if they have a default value
     UMLAttributeList atl = c->getAttributeList();
-    UMLAttribute *at;
-    for(at = atl.first(); at ; at = atl.next()) {
-        if(!at->getInitialValue().isEmpty())
+
+    foreach (UMLAttribute* at , atl ) {
+        if (!at->getInitialValue().isEmpty())
             atdefval.append(at);
         switch(at->getVisibility()) {
           case Uml::Visibility::Public:
@@ -423,28 +416,25 @@ void PerlWriter::writeAttributes(UMLClassifier *c, QTextStream &perl) {
         }
     }
 
-
-    if(forceSections() || atpub.count()) {
+    if (forceSections() || atpub.count()) {
         writeAttributes(atpub,perl);
     }
     /* not needed as writeAttributes only writes documentation
-    if(forceSections() || atprot.count()) {
+    if (forceSections() || atprot.count()) {
     writeAttributes(atprot,perl);
     }
 
-    if(forceSections() || atpriv.count()) {
+    if (forceSections() || atpriv.count()) {
     writeAttributes(atpriv,perl);
     }
     */
 }
 
-
 void PerlWriter::writeAttributes(UMLAttributeList &atList, QTextStream &perl)
 {
     perl << m_endl << "=head1 PUBLIC ATTRIBUTES" << m_endl << m_endl;
     perl << "=pod "  << m_endl << m_endl ;
-    for (UMLAttribute *at = atList.first(); at ; at = atList.next())
-    {
+    foreach (UMLAttribute *at , atList ) {
         if (forceDoc() || !at->getDoc().isEmpty())
         {
             perl  << "=head3 " << cleanName(at->getName()) << m_endl << m_endl ;
@@ -455,7 +445,8 @@ void PerlWriter::writeAttributes(UMLAttributeList &atList, QTextStream &perl)
     return;
 }
 
-QStringList PerlWriter::defaultDatatypes() {
+QStringList PerlWriter::defaultDatatypes()
+{
     QStringList l;
     l.append("$");
     l.append("@");
@@ -463,8 +454,8 @@ QStringList PerlWriter::defaultDatatypes() {
     return l;
 }
 
-const QStringList PerlWriter::reservedKeywords() const {
-
+const QStringList PerlWriter::reservedKeywords() const
+{
     static QStringList keywords;
 
     if (keywords.isEmpty()) {
