@@ -26,7 +26,6 @@
 #include "../codeblockwithcomments.h"
 #include "../umldoc.h"
 
-#include "classifierinfo.h"
 #include "rubyclassifiercodedocument.h"
 
 #include "rubycodegenerationpolicy.h"
@@ -82,9 +81,6 @@ public:
     // Other methods
     //
 
-    // general purpose function we may reuse for all types of Ruby code documents
-    QString capitalizeFirstLetter(const QString &string);
-
     /**
      * Utility function for getting the ruby code generation policy.
      */
@@ -125,7 +121,7 @@ protected:
     /** create the codeblock that will represent the class declaration
      *  for this classifier
      */
-    CodeBlockWithComments * createClassDecl ( UMLClassifier *c, ClassifierInfo *info, RubyClassifierCodeDocument * doc);
+    CodeBlockWithComments * createClassDecl ( UMLClassifier *c, RubyClassifierCodeDocument * doc);
 
 };
 
