@@ -4,7 +4,7 @@
     begin                : Sat Dec 21 2002
     copyright            : Vincent Decorges
     email                : vincent.decorges@eivd.ch
-      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
+      (C) 2003-2008  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,74 +21,71 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
 
-#include "classifierinfo.h"
-#include "../umldoc.h"
-#include "../umlattributelist.h"
-#include "../association.h"
-#include "../attribute.h"
-#include "../classifier.h"
-#include "../operation.h"
-#include "../umlnamespace.h"
+#include "umldoc.h"
+#include "umlattributelist.h"
+#include "association.h"
+#include "attribute.h"
+#include "classifier.h"
+#include "operation.h"
+#include "umlnamespace.h"
 
-RubyWriter::RubyWriter() {
+RubyWriter::RubyWriter()
+{
 }
 
-RubyWriter::~RubyWriter() {}
+RubyWriter::~RubyWriter()
+{
+}
 
-void RubyWriter::writeClass(UMLClassifier *c) {
-    if(!c) {
-        kDebug()<<"Cannot write class of NULL concept!" << endl;
+void RubyWriter::writeClass(UMLClassifier *c)
+{
+    if (!c) {
+        uDebug()<<"Cannot write class of NULL concept!";
         return;
     }
 
-    QString classname = cleanName(c->getName());
-
     UMLClassifierList superclasses = c->getSuperClasses();
     UMLAssociationList aggregations = c->getAggregations();
     UMLAssociationList compositions = c->getCompositions();
 
     //find an appropriate name for our file
-    QString fileName = findFileName(c, ".rb");
-    if (fileName.isEmpty()) {
+    fileName_ = findFileName(c, ".rb");
+    if (fileName_.isEmpty()) {
         emit codeGenerated(c, false);
         return;
     }
 
     QFile fileh;
-    if( !openFile(fileh, fileName) ) {
+    if ( !openFile(fileh, fileName_) ) {
         emit codeGenerated(c, false);
         return;
     }
     QTextStream h(&fileh);
 
-    // preparations
-    classifierInfo = new ClassifierInfo(c);
-    classifierInfo->fileName = fileName;
-    classifierInfo->className = cleanName(c->getName());
+    className_ = cleanName(c->getName());
 
     //////////////////////////////
     //Start generating the code!!
     /////////////////////////////
 
-
     //try to find a heading file (license, coments, etc)
     QString str;
 
     str = getHeadingFile(".rb");
-    if(!str.isEmpty()) {
-        str.replace(QRegExp("%filename%"), fileName);
-        str.replace(QRegExp("%filepath%"), fileh.name());
+    if (!str.isEmpty()) {
+        str.replace(QRegExp("%filename%"), fileName_);
+        str.replace(QRegExp("%filepath%"), fileh.fileName());
         h<<str<<m_endl;
     }
 
-    if(forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->getDoc().isEmpty()) {
         QString docStr = c->getDoc();
         docStr.replace(QRegExp("\\n"), "\n# ");
-        docStr.replace("@ref ", "");
+        docStr.remove("@ref ");
         docStr.replace("@see", "_See_");
         docStr.replace("@short", "_Summary_");
         docStr.replace("@author", "_Author_");
@@ -100,10 +97,10 @@ void RubyWriter::writeClass(UMLClassifier *c) {
     // write inheritances out
     UMLClassifier *concept;
 
-    h<< "class " << cppToRubyType(classname) << (superclasses.count() > 0 ? " < ":"");
+    h<< "class " << cppToRubyType(className_) << (superclasses.count() > 0 ? " < ":"");
 
     int i = 0;
-    for (concept = superclasses.first(); concept; concept = superclasses.next()) {
+    foreach (concept , superclasses ) {
         if (i == 0) {
             h << cppToRubyType(concept->getName()) << m_endl;
         } else {
@@ -117,15 +114,15 @@ void RubyWriter::writeClass(UMLClassifier *c) {
     h << m_endl;
 
     // write comment for sub-section IF needed
-    if (forceDoc() || classifierInfo->hasAccessorMethods) {
+    if (forceDoc() || c->hasAccessorMethods()) {
         h << m_indentation << "#" << m_endl;
         h << m_indentation << "# Accessor Methods" << m_endl;
         h << m_indentation << "#" << m_endl << m_endl;
 
         // Accessor methods for attributes
-        writeAttributeMethods(&(classifierInfo->atpub), Uml::Visibility::Public, h);
-        writeAttributeMethods(&(classifierInfo->atprot), Uml::Visibility::Protected, h);
-        writeAttributeMethods(&(classifierInfo->atpriv), Uml::Visibility::Private, h);
+        writeAttributeMethods(c->getAttributeList(Uml::Visibility::Public), Uml::Visibility::Public, h);
+        writeAttributeMethods(c->getAttributeList(Uml::Visibility::Protected), Uml::Visibility::Protected, h);
+        writeAttributeMethods(c->getAttributeList(Uml::Visibility::Private), Uml::Visibility::Private, h);
         h << m_endl;
     }
 
@@ -140,14 +137,11 @@ void RubyWriter::writeClass(UMLClassifier *c) {
     emit codeGenerated(c, true);
 }
 
-
-////////////////////////////////////////////////////////////////////////////////////
-//  Helper Methods
-
-QString RubyWriter::cppToRubyType(const QString &typeStr) {
+QString RubyWriter::cppToRubyType(const QString &typeStr)
+{
     QString type = cleanName(typeStr);
-    type.replace("const ", "");
-    type.replace(QRegExp("[*&\\s]"), "");
+    type.remove("const ");
+    type.remove(QRegExp("[*&\\s]"));
     type.replace(QRegExp("[<>]"), "_");
     type.replace("QStringList", "Array");
     type.replace("QString", "String");
@@ -160,26 +154,23 @@ QString RubyWriter::cppToRubyType(const QString &typeStr) {
     return type;
 }
 
-QString RubyWriter::cppToRubyName(const QString &nameStr) {
+QString RubyWriter::cppToRubyName(const QString &nameStr)
+{
     QString name = cleanName(nameStr);
-    name.replace(QRegExp("^m_"), "");
-    name.replace(QRegExp("^[pbn](?=[A-Z])"), "");
-    name = name.mid(0, 1).lower() + name.mid(1);
+    name.remove(QRegExp("^m_"));
+    name.remove(QRegExp("^[pbn](?=[A-Z])"));
+    name = name.mid(0, 1).toLower() + name.mid(1);
     return name;
 }
 
-void RubyWriter::writeOperations(UMLClassifier *c,QTextStream &h) {
-
+void RubyWriter::writeOperations(UMLClassifier *c,QTextStream &h)
+{
     //Lists to store operations  sorted by scope
     UMLOperationList oppub,opprot,oppriv;
 
-    oppub.setAutoDelete(false);
-    opprot.setAutoDelete(false);
-    oppriv.setAutoDelete(false);
-
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
-    for(UMLOperation *op = opl.first(); op ; op = opl.next()) {
+    foreach (UMLOperation *op , opl ) {
         switch(op->getVisibility()) {
         case Uml::Visibility::Public:
             oppub.append(op);
@@ -198,18 +189,17 @@ void RubyWriter::writeOperations(UMLClassifier *c,QTextStream &h) {
     QString classname(cleanName(c->getName()));
 
     //write operations to file
-    if(forceSections() || !oppub.isEmpty()) {
+    if (forceSections() || !oppub.isEmpty()) {
         writeOperations(classname, oppub, Uml::Visibility::Public, h);
     }
 
-    if(forceSections() || !opprot.isEmpty()) {
+    if (forceSections() || !opprot.isEmpty()) {
         writeOperations(classname, opprot, Uml::Visibility::Protected, h);
     }
 
-    if(forceSections() || !oppriv.isEmpty()) {
+    if (forceSections() || !oppriv.isEmpty()) {
         writeOperations(classname, oppriv, Uml::Visibility::Private, h);
     }
-
 }
 
 void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opList,
@@ -232,13 +222,13 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
         break;
     }
 
-    for (op=opList.first(); op ; op=opList.next()) {
+    foreach (op ,  opList ) {
         QString methodName = cleanName(op->getName());
         QStringList commentedParams;
 
         // Skip destructors, and operator methods which
         // can't be defined in ruby
-        if (    methodName.startsWith("~")
+        if (    methodName.startsWith('~')
                 || methodName == "operator ="
                 || methodName == "operator --"
                 || methodName == "operator ++"
@@ -251,8 +241,8 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
             methodName = "initialize";
         }
 
-        methodName.replace("operator ", "");
-        methodName = methodName.mid(0, 1).lower() + methodName.mid(1);
+        methodName.remove("operator ");
+        methodName = methodName.mid(0, 1).toLower() + methodName.mid(1);
 
         UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
@@ -273,20 +263,20 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
             docStr.replace(" m_", " ");
             docStr.replace(QRegExp("\\s[npb](?=[A-Z])"), " ");
             QRegExp re_params("@param (\\w)(\\w*)");
-            int pos = re_params.search(docStr);
+            int pos = re_params.indexIn(docStr);
             while (pos != -1) {
                 docStr.replace( re_params.cap(0),
-                                QString("@param _") + re_params.cap(1).lower() + re_params.cap(2) + '_' );
-                commentedParams.append(re_params.cap(1).lower() + re_params.cap(2));
+                                QString("@param _") + re_params.cap(1).toLower() + re_params.cap(2) + '_' );
+                commentedParams.append(re_params.cap(1).toLower() + re_params.cap(2));
 
                 pos += re_params.matchedLength() + 3;
-                pos = re_params.search(docStr, pos);
+                pos = re_params.indexIn(docStr, pos);
             }
 
             docStr.replace("\n", QString("\n") + m_indentation + "# ");
 
             // Write parameter documentation
-            for (at = atl.first(); at ; at = atl.next()) {
+            foreach ( at , atl ) {
                 // Only write an individual @param entry if one hasn't been found already
                 // in the main doc comment
                 if (commentedParams.contains(cppToRubyName(at->getName())) == 0) {
@@ -299,7 +289,7 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
                 }
             }
 
-            docStr.replace("@ref ", "");
+            docStr.remove("@ref ");
             docStr.replace("@param", "*");
             docStr.replace("@return", "* _returns_");
 
@@ -307,14 +297,14 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
             // must be indented correctly. If they aren't a list
             // item starting with '# *', then indent the text with
             // three spaces, '#   ', to line up with the list item.
-            pos = docStr.find("# *");
+            pos = docStr.indexOf("# *");
             QRegExp re_linestart("# (?!\\*)");
-            pos = re_linestart.search(docStr, pos);
+            pos = re_linestart.indexIn(docStr, pos);
             while (pos > 0) {
                 docStr.insert(pos + 1, "  ");
 
                 pos += re_linestart.matchedLength() + 2;
-                pos = re_linestart.search(docStr, pos);
+                pos = re_linestart.indexIn(docStr, pos);
             }
 
             h << m_indentation << "# "<< docStr << m_endl;
@@ -328,7 +318,7 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
         h<< m_indentation << "def " + methodName << "(";
 
         int j=0;
-        for (at = atl.first(); at; at = atl.next(), j++) {
+        foreach (at , atl ) {
             QString nameStr = cppToRubyName(at->getName());
             if (j > 0) {
                 h << ", " << nameStr;
@@ -338,11 +328,19 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
             h << (!(at->getInitialValue().isEmpty()) ?
                 (QString(" = ") + cppToRubyType(at->getInitialValue())) :
                 QString(""));
+            j++;
         }
 
         h <<")" << m_endl;
 
-        h << m_indentation << m_indentation << m_endl;
+        // write body
+        QString sourceCode = op->getSourceCode();
+        if (sourceCode.isEmpty()) {  // empty method body
+            h << m_indentation << m_indentation << m_endl;
+        }
+        else {
+            h << formatSourceCode(sourceCode, m_indentation + m_indentation);
+        }
 
         h << m_indentation << "end" << m_endl << m_endl;
 
@@ -350,17 +348,15 @@ void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opL
 
 }
 
-// this is for writing file attribute methods
-//
-void RubyWriter::writeAttributeMethods(UMLAttributeList *attribs,
+void RubyWriter::writeAttributeMethods(UMLAttributeList attribs,
                                       Uml::Visibility visibility, QTextStream &stream)
 {
     // return now if NO attributes to work on
-    if (attribs->count() == 0 || visibility == Uml::Visibility::Private)
+    if (attribs.count() == 0 || visibility == Uml::Visibility::Private)
         return;
 
     UMLAttribute *at;
-    for(at=attribs->first(); at; at=attribs->next())
+    foreach (at ,  attribs)
     {
         QString varName = cppToRubyName(cleanName(at->getName()));
 
@@ -375,8 +371,8 @@ void RubyWriter::writeSingleAttributeAccessorMethods(
         QTextStream &h)
 {
     QString description = descr;
-    description.replace(QRegExp("m_[npb](?=[A-Z])"), "");
-    description.replace("m_", "");
+    description.remove(QRegExp("m_[npb](?=[A-Z])"));
+    description.remove("m_");
     description.replace("\n", QString("\n") + m_indentation + "# ");
 
     if (!description.isEmpty()) {
@@ -388,15 +384,13 @@ void RubyWriter::writeSingleAttributeAccessorMethods(
     return;
 }
 
-/**
- * returns "Ruby"
- */
-Uml::Programming_Language RubyWriter::getLanguage() {
+Uml::Programming_Language RubyWriter::getLanguage()
+{
     return Uml::pl_Ruby;
 }
 
-const QStringList RubyWriter::reservedKeywords() const {
-
+const QStringList RubyWriter::reservedKeywords() const
+{
     static QStringList keywords;
 
     if (keywords.isEmpty()) {
