@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2007                                               *
+ *   copyright (C) 2006-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,7 +14,7 @@
 
 #include <stdio.h>
 // qt/kde includes
-#include <qregexp.h>
+#include <QtCore/QRegExp>
 #include <kdebug.h>
 // app includes
 #include "import_utils.h"
@@ -26,22 +26,26 @@
 #include "../operation.h"
 #include "../attribute.h"
 
-PascalImport::PascalImport() : NativeImportBase("//") {
+PascalImport::PascalImport() : NativeImportBase("//")
+{
     setMultiLineComment("(*", "*)");
     setMultiLineAltComment("{", "}");
     initVars();
 }
 
-PascalImport::~PascalImport() {
+PascalImport::~PascalImport()
+{
 }
 
-void PascalImport::initVars() {
+void PascalImport::initVars()
+{
     m_inInterface = false;
     m_section = sect_NONE;
     NativeImportBase::m_currentAccess = Uml::Visibility::Public;
 }
 
-void PascalImport::fillSource(const QString& word) {
+void PascalImport::fillSource(const QString& word)
+{
     QString lexeme;
     const uint len = word.length();
     for (uint i = 0; i < len; i++) {
@@ -65,10 +69,11 @@ void PascalImport::fillSource(const QString& word) {
         m_source.append(lexeme);
 }
 
-void PascalImport::checkModifiers(bool& isVirtual, bool& isAbstract) {
-    const uint srcLength = m_source.count();
+void PascalImport::checkModifiers(bool& isVirtual, bool& isAbstract)
+{
+    const int srcLength = m_source.count();
     while (m_srcIndex < srcLength - 1) {
-        QString lookAhead = m_source[m_srcIndex + 1].lower();
+        QString lookAhead = m_source[m_srcIndex + 1].toLower();
         if (lookAhead != "virtual" && lookAhead != "abstract" &&
             lookAhead != "override" &&
             lookAhead != "register" && lookAhead != "cdecl" &&
@@ -85,14 +90,15 @@ void PascalImport::checkModifiers(bool& isVirtual, bool& isAbstract) {
     }
 }
 
-bool PascalImport::parseStmt() {
-    const uint srcLength = m_source.count();
-    QString keyword = m_source[m_srcIndex].lower();
-    //kDebug() << '"' << keyword << '"' << endl;
+bool PascalImport::parseStmt()
+{
+    const int srcLength = m_source.count();
+    QString keyword = m_source[m_srcIndex].toLower();
+    //uDebug() << '"' << keyword << '"';
     if (keyword == "uses") {
         while (m_srcIndex < srcLength - 1) {
             QString unit = advance();
-            const QString& prefix = unit.lower();
+            const QString& prefix = unit.toLower();
             if (prefix == "sysutils" || prefix == "types" || prefix == "classes" ||
                 prefix == "graphics" || prefix == "controls" || prefix == "strings" ||
                 prefix == "forms" || prefix == "windows" || prefix == "messages" ||
@@ -193,7 +199,7 @@ bool PascalImport::parseStmt() {
             m_scopeIndex--;
             m_currentAccess = Uml::Visibility::Public;
         } else {
-            kError() << "importPascal: too many \"end\"" << endl;
+            uError() << "importPascal: too many \"end\"";
         }
         skipStmt();
         return true;
@@ -215,7 +221,7 @@ bool PascalImport::parseStmt() {
             advance();
             const uint MAX_PARNAMES = 16;
             while (m_srcIndex < srcLength && m_source[m_srcIndex] != ")") {
-                QString nextToken = m_source[m_srcIndex + 1].lower();
+                QString nextToken = m_source[m_srcIndex + 1].toLower();
                 Uml::Parameter_Direction dir = Uml::pd_In;
                 if (nextToken == "var") {
                     dir = Uml::pd_InOut;
@@ -230,22 +236,22 @@ bool PascalImport::parseStmt() {
                 uint parNameCount = 0;
                 do {
                     if (parNameCount >= MAX_PARNAMES) {
-                        kError() << "MAX_PARNAMES is exceeded at " << name << endl;
+                        uError() << "MAX_PARNAMES is exceeded at " << name;
                         break;
                     }
                     parName[parNameCount++] = advance();
                 } while (advance() == ",");
                 if (m_source[m_srcIndex] != ":") {
-                    kError() << "importPascal: expecting ':' at " << m_source[m_srcIndex] << endl;
+                    uError() << "importPascal: expecting ':' at " << m_source[m_srcIndex];
                     skipStmt();
                     break;
                 }
                 nextToken = advance();
-                if (nextToken.lower() == "array") {
-                    nextToken = advance().lower();
+                if (nextToken.toLower() == "array") {
+                    nextToken = advance().toLower();
                     if (nextToken != "of") {
-                        kError() << "importPascal(" << name << "): expecting 'array OF' at "
-                                  << nextToken << endl;
+                        uError() << "importPascal(" << name << "): expecting 'array OF' at "
+                                  << nextToken;
                         skipStmt();
                         return false;
                     }
@@ -262,8 +268,8 @@ bool PascalImport::parseStmt() {
         QString returnType;
         if (keyword == "function") {
             if (advance() != ":") {
-                kError() << "importPascal: expecting \":\" at function "
-                        << name << endl;
+                uError() << "importPascal: expecting \":\" at function "
+                        << name;
                 return false;
             }
             returnType = advance();
@@ -286,11 +292,10 @@ bool PascalImport::parseStmt() {
         const QString& name = m_source[m_srcIndex];
         QString nextToken = advance();
         if (nextToken != "=") {
-            kDebug() << "PascalImport::parseStmt(" << name << "): "
-                << "expecting '=' at " << nextToken << endl;
+            uDebug() << name << ": expecting '=' at " << nextToken;
             return false;
         }
-        keyword = advance().lower();
+        keyword = advance().toLower();
         if (keyword == "(") {
             // enum type
             UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Enum,
@@ -337,8 +342,8 @@ bool PascalImport::parseStmt() {
                     Import_Utils::createGeneralization(klass, parent);
                 } while (advance() == ",");
                 if (m_source[m_srcIndex] != ")") {
-                    kError() << "PascalImport: expecting \")\" at "
-                        << m_source[m_srcIndex] << endl;
+                    uError() << "PascalImport: expecting \")\" at "
+                        << m_source[m_srcIndex];
                     return false;
                 }
                 lookAhead = m_source[m_srcIndex + 1];
@@ -363,7 +368,7 @@ bool PascalImport::parseStmt() {
             return true;
         }
         if (keyword == "function" || keyword == "procedure") {
-            UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Datatype, name,
+            /*UMLObject *ns =*/ Import_Utils::createUMLObject(Uml::ot_Datatype, name,
                                                           m_scope[m_scopeIndex], m_comment);
             if (m_source[m_srcIndex + 1] == "(")
                 skipToClosing('(');
@@ -375,7 +380,7 @@ bool PascalImport::parseStmt() {
     }
     // At this point we need a class because we're expecting its member attributes.
     if (m_klass == NULL) {
-        kDebug() << "importPascal: skipping " << m_source[m_srcIndex] << endl;
+        uDebug() << "importPascal: skipping " << m_source[m_srcIndex];
         skipStmt();
         return true;
     }
@@ -387,8 +392,8 @@ bool PascalImport::parseStmt() {
         name = m_source[m_srcIndex];
     }
     if (advance() != ":") {
-        kError() << "PascalImport: expecting \":\" at " << name << " "
-                  << m_source[m_srcIndex] << endl;
+        uError() << "PascalImport: expecting \":\" at " << name << " "
+                  << m_source[m_srcIndex];
         skipStmt();
         return true;
     }
