@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -16,10 +16,14 @@
 
 #include <kinputdialog.h>
 #include <klocale.h>
-#include <kbuttonbox.h>
+#include <kdialogbuttonbox.h>
 #include <kdebug.h>
-#include <qlayout.h>
-#include <qstringlist.h>
+
+#include <QLayout>
+#include <QStringList>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QGridLayout>
 
 ActivityPage::ActivityPage( QWidget * pParent, StateWidget * pWidget ) : QWidget( pParent ) {
     m_pStateWidget = pWidget;
@@ -31,11 +35,11 @@ ActivityPage::~ActivityPage() {}
 
 void ActivityPage::setupPage() {
     int margin = fontMetrics().height();
-    
+
     QVBoxLayout * mainLayout = new QVBoxLayout( this );
     mainLayout -> setSpacing(10);
 
-    m_pActivityGB = new QGroupBox(i18n("Activities"), this );
+    m_pActivityGB = new Q3GroupBox(i18n("Activities"), this );
 
     // vertical box layout for the activity lists, arrow buttons and the button box
     QVBoxLayout* listVBoxLayout = new QVBoxLayout( m_pActivityGB );
@@ -43,13 +47,15 @@ void ActivityPage::setupPage() {
     listVBoxLayout -> setSpacing ( 10 );
 
     //horizontal box contains the list box and the move up/down buttons
-    QHBoxLayout* listHBoxLayout = new QHBoxLayout( listVBoxLayout );
-    
-    m_pActivityLB = new QListBox(m_pActivityGB );
-   
+    QHBoxLayout* listHBoxLayout = new QHBoxLayout();
+    listVBoxLayout->addItem( listHBoxLayout );
+
+    m_pActivityLB = new Q3ListBox(m_pActivityGB );
+
     listHBoxLayout -> addWidget(m_pActivityLB);
 
-    QVBoxLayout * buttonLayout = new QVBoxLayout( listHBoxLayout );
+    QVBoxLayout * buttonLayout = new QVBoxLayout();
+    listHBoxLayout->addItem( buttonLayout );
 
     m_pTopArrowB = new KArrowButton( m_pActivityGB );
     m_pTopArrowB -> setEnabled( false );
@@ -67,12 +73,14 @@ void ActivityPage::setupPage() {
     m_pBottomArrowB -> setEnabled( false );
     buttonLayout -> addWidget( m_pBottomArrowB );
 
-   
-    KButtonBox* buttonBox = new KButtonBox(m_pActivityGB);
-    buttonBox->addButton( i18n("New Activity..."), this, SLOT(slotNewActivity()) );
-    m_pDeleteActivityButton = buttonBox->addButton( i18n("Delete"),
+
+    KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pActivityGB);
+    buttonBox->addButton( i18n("New Activity..."), KDialogButtonBox::ActionRole,
+                          this, SLOT(slotNewActivity()) );
+    m_pDeleteActivityButton = buttonBox->addButton( i18n("Delete"), KDialogButtonBox::ActionRole,
                               this, SLOT(slotDelete()) );
-    m_pRenameButton = buttonBox->addButton( i18n("Rename"), this, SLOT(slotRename()) );
+    m_pRenameButton = buttonBox->addButton( i18n("Rename"), KDialogButtonBox::ActionRole,
+                                            this, SLOT(slotRename()) );
     listVBoxLayout->addWidget(buttonBox);
 
     mainLayout -> addWidget( m_pActivityGB );
@@ -86,19 +94,19 @@ void ActivityPage::setupPage() {
     }
 
     //now setup the signals
-    connect(m_pActivityLB, SIGNAL(clicked(QListBoxItem *)), this, SLOT(slotClicked(QListBoxItem *)));
-    connect(m_pActivityLB, SIGNAL(rightButtonPressed(QListBoxItem *, const QPoint &)),
-            this, SLOT(slotRightButtonPressed(QListBoxItem *, const QPoint &)));
+    connect(m_pActivityLB, SIGNAL(clicked(Q3ListBoxItem *)), this, SLOT(slotClicked(Q3ListBoxItem *)));
+    connect(m_pActivityLB, SIGNAL(rightButtonPressed(Q3ListBoxItem *, const QPoint &)),
+            this, SLOT(slotRightButtonPressed(Q3ListBoxItem *, const QPoint &)));
 
-    connect(m_pActivityLB, SIGNAL(rightButtonClicked(QListBoxItem *, const QPoint &)),
-            this, SLOT(slotRightButtonClicked(QListBoxItem *, const QPoint &)));
+    connect(m_pActivityLB, SIGNAL(rightButtonClicked(Q3ListBoxItem *, const QPoint &)),
+            this, SLOT(slotRightButtonClicked(Q3ListBoxItem *, const QPoint &)));
 
     connect( m_pTopArrowB, SIGNAL( clicked() ), this, SLOT( slotTopClicked() ) );
     connect( m_pUpArrowB, SIGNAL( clicked() ), this, SLOT( slotUpClicked() ) );
     connect( m_pDownArrowB, SIGNAL( clicked() ), this, SLOT( slotDownClicked() ) );
     connect( m_pBottomArrowB, SIGNAL( clicked() ), this, SLOT( slotBottomClicked() ) );
-     
-    connect( m_pActivityLB, SIGNAL( doubleClicked( QListBoxItem* ) ), this, SLOT( slotDoubleClicked( QListBoxItem* ) ) );
+
+    connect( m_pActivityLB, SIGNAL( doubleClicked( Q3ListBoxItem* ) ), this, SLOT( slotDoubleClicked( Q3ListBoxItem* ) ) );
 
     enableWidgets(false);
 }
@@ -112,8 +120,9 @@ void ActivityPage::updateActivities() {
     m_pStateWidget -> setActivities( list );
 }
 
-void ActivityPage::slotMenuSelection( int sel ) {
-    switch( sel ) {
+void ActivityPage::slotMenuSelection(QAction* action) {
+    ListPopupMenu::Menu_Type sel = m_pMenu->getMenuType(action);
+    switch(sel) {
     case ListPopupMenu::mt_New_Activity:
         slotNewActivity();
         break;
@@ -125,6 +134,9 @@ void ActivityPage::slotMenuSelection( int sel ) {
     case ListPopupMenu::mt_Rename:
         slotRename();
         break;
+
+    default:
+        uDebug() << "Menu_Type " << sel << " not implemented" << endl;
     }
 }
 
@@ -157,7 +169,7 @@ void ActivityPage::slotRename() {
     }
 }
 
-void ActivityPage::slotRightButtonClicked(QListBoxItem * /*item*/, const QPoint &/* p*/) {
+void ActivityPage::slotRightButtonClicked(Q3ListBoxItem * /*item*/, const QPoint &/* p*/) {
     if(m_pMenu) {
         m_pMenu->hide();
         disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotMenuSelection(int)));
@@ -166,7 +178,7 @@ void ActivityPage::slotRightButtonClicked(QListBoxItem * /*item*/, const QPoint
     }
 }
 
-void ActivityPage::slotRightButtonPressed(QListBoxItem * item, const QPoint & p)
+void ActivityPage::slotRightButtonPressed(Q3ListBoxItem * item, const QPoint & p)
 {
     ListPopupMenu::Menu_Type type = ListPopupMenu::mt_Undefined;
     if( item ) { //pressed on an item
@@ -176,14 +188,14 @@ void ActivityPage::slotRightButtonPressed(QListBoxItem * item, const QPoint & p)
     }
 
     if(m_pMenu) {
-        m_pMenu -> hide();
-        disconnect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotMenuSelection(int)));
+        m_pMenu->hide();
+        disconnect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotMenuSelection(QAction*)));
         delete m_pMenu;
         m_pMenu = 0;
     }
     m_pMenu = new ListPopupMenu(this, type);
     m_pMenu->popup(p);
-    connect(m_pMenu, SIGNAL(activated(int)), this, SLOT(slotMenuSelection(int)));
+    connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotMenuSelection(QAction*)));
 }
 
 
@@ -199,7 +211,7 @@ void ActivityPage::slotTopClicked() {
     m_pActivityLB->removeItem( index );
     m_pActivityLB->insertItem( currentString, 0 );
     //set the moved item selected
-    QListBoxItem* item = m_pActivityLB->item( 0 );
+    Q3ListBoxItem* item = m_pActivityLB->item( 0 );
     m_pActivityLB->setSelected( item, true );
 
     slotClicked(item);
@@ -219,7 +231,7 @@ void ActivityPage::slotUpClicked() {
     m_pActivityLB -> changeItem( currentString, index -1 );
     m_pActivityLB -> changeItem( aboveString, index );
     //set the moved atttribute selected
-    QListBoxItem * item = m_pActivityLB -> item( index - 1 );
+    Q3ListBoxItem * item = m_pActivityLB -> item( index - 1 );
     m_pActivityLB -> setSelected( item, true );
     slotClicked(item);
 }
@@ -238,7 +250,7 @@ void ActivityPage::slotDownClicked() {
     m_pActivityLB -> changeItem( currentString, index + 1 );
     m_pActivityLB -> changeItem( belowString, index );
     //set the moved atttribute selected
-    QListBoxItem * item = m_pActivityLB -> item( index + 1 );
+    Q3ListBoxItem * item = m_pActivityLB -> item( index + 1 );
     m_pActivityLB -> setSelected( item, true );
     slotClicked(item);
 }
@@ -250,20 +262,20 @@ void ActivityPage::slotBottomClicked() {
     //shouldn't occur, but just in case
     if( count <= 1 || index >= count - 1 )
         return;
-   
+
     //swap the text around in the ListBox
     QString currentString = m_pActivityLB->text( index );
     m_pActivityLB->removeItem( index );
     m_pActivityLB->insertItem( currentString, m_pActivityLB->count() );
     //set the moved item selected
-    QListBoxItem* item = m_pActivityLB->item( m_pActivityLB->count() - 1 );
+    Q3ListBoxItem* item = m_pActivityLB->item( m_pActivityLB->count() - 1 );
     m_pActivityLB->setSelected( item, true );
 
    slotClicked( item );
 }
 
 
-void ActivityPage::slotClicked(QListBoxItem *item) {
+void ActivityPage::slotClicked(Q3ListBoxItem *item) {
     //make sure clicked on an item
     if(!item) {
         enableWidgets(false);
@@ -273,7 +285,7 @@ void ActivityPage::slotClicked(QListBoxItem *item) {
     }
 }
 
-void ActivityPage::slotDoubleClicked(QListBoxItem* item) {
+void ActivityPage::slotDoubleClicked(Q3ListBoxItem* item) {
     if (item) {
         slotRename();
     }
@@ -310,7 +322,7 @@ void ActivityPage::enableWidgets(bool state) {
         m_pTopArrowB->setEnabled(true);
         m_pUpArrowB->setEnabled(true);
         m_pDownArrowB->setEnabled(false);
-        m_pBottomArrowB->setEnabled(false); 
+        m_pBottomArrowB->setEnabled(false);
    } else {
         m_pTopArrowB->setEnabled(true);
         m_pUpArrowB->setEnabled(true);
