@@ -14,9 +14,8 @@
 #define ASSOCPAGE_H
 
 #include <qwidget.h>
-#include <qgroupbox.h>
-#include <qlistbox.h>
-#include <qptrlist.h>
+#include <q3groupbox.h>
+#include <q3listbox.h>
 
 #include "../umlobject.h"
 #include "../umlview.h"
@@ -29,11 +28,6 @@
  * Displays a page on the tabbed dialog window of @ref ClassPropDlg.
  * The page shows all the Associations that belong to a UMLClassifier.
  *
- *
- * @see ClassPropDlg
-
- * @see UMLClassifier
- *
  * @short The page shows all the Associations that belong to a UMLClassifier.
  * @author Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
@@ -57,8 +51,8 @@ public:
 private:
     UMLObject * m_pObject;
     UMLView * m_pView;
-    QListBox * m_pAssocLB;
-    QGroupBox * m_pAssocGB;
+    Q3ListBox * m_pAssocLB;
+    Q3GroupBox * m_pAssocGB;
     AssociationWidgetList m_List;
     ListPopupMenu * m_pMenu;
 
@@ -67,10 +61,10 @@ private:
      */
     void fillListBox();
 public slots:
-    void slotDoubleClick(QListBoxItem * i);
-    void slotRightButtonClicked(QListBoxItem */* item*/, const QPoint &/* p*/);
-    void slotRightButtonPressed(QListBoxItem * item, const QPoint & p);
-    void slotPopupMenuSel(int id);
+    void slotDoubleClick(Q3ListBoxItem * i);
+    void slotRightButtonClicked(Q3ListBoxItem * /* item*/, const QPoint & /* p*/);
+    void slotRightButtonPressed(Q3ListBoxItem * item, const QPoint & p);
+    void slotPopupMenuSel(QAction* action);
 };
 
 #endif
