@@ -1,30 +1,28 @@
-
 /***************************************************************************
-                          codeeditor.h  -  description
-                             -------------------
-    begin                : Fri Aug 1 2003
-    copyright            : (C) 2003 by Brian Thomas
-    email                : brian.thomas@gsfc.nasa.gov
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003 Brian Thomas  <brian.thomas@gsfc.nasa.gov>         *
+ *   copyright (C) 2004-2008                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CODEEDITOR_H
 #define CODEEDITOR_H
 
-#include <qpopupmenu.h>
-#include <qstring.h>
-#include <qlabel.h>
-#include <qtextedit.h>
-#include "../codeviewerstate.h"
-#include "../textblocklist.h"
+#include <QtCore/QString>
+#include <QtCore/QList>
+#include <QtGui/QLabel>
+//#include <QtGui/QTextEdit>
+#include <q3textedit.h>
+#include <q3popupmenu.h>
+
+#include <kmenu.h>
+
+#include "codeviewerstate.h"
+#include "textblocklist.h"
 
 class UMLObject;
 
@@ -35,17 +33,44 @@ class CodeClassFieldDeclarationBlock;
 class CodeMethodBlock;
 class CodeBlockWithComments;
 class HierarchicalCodeBlock;
-
-class TextBlockInfo;
 class TextBlock;
-class ParaInfo;
 
-class CodeEditor : public QTextEdit
+
+class ParaInfo
+{
+public:
+    int start; // this is a relative offset from the beginning of the tblock
+    int size;
+    QColor fgcolor;
+    QColor bgcolor;
+    bool isEditable;
+
+    ParaInfo () { isEditable = false; }
+};
+
+
+class TextBlockInfo
+{
+public:
+    QList<ParaInfo*> m_paraList;
+    UMLObject * m_parent;
+    QString displayName;
+    bool isClickable;
+    bool isCodeAccessorMethod;
+
+    TextBlockInfo () { m_parent = 0; isClickable = false; isCodeAccessorMethod = false; }
+    void setParent(UMLObject *p = 0) { m_parent = p; }
+    UMLObject * getParent() { return m_parent; }
+};
+
+
+class CodeEditor : public Q3TextEdit
 {
     Q_OBJECT
 public:
 
-    explicit CodeEditor ( const QString & text, const QString & context = QString(), CodeViewerDialog * parent = 0, const char * name = 0 , CodeDocument * doc = 0);
+    explicit CodeEditor ( const QString & text, const QString & context = QString(),
+                          CodeViewerDialog * parent = 0, const char * name = 0, CodeDocument * doc = 0);
     explicit CodeEditor ( CodeViewerDialog * parent, const char* name = 0, CodeDocument * doc = 0);
     ~CodeEditor ();
 
@@ -54,15 +79,15 @@ public:
 
 protected:
 
-    bool close ( bool alsoDelete );
+    bool close ();
 
     // various methods for appending various types of text blocks in the editor.
     void appendText (TextBlock * tblock);
     void appendText (HierarchicalCodeBlock * hblock);
-    void appendText (CodeClassFieldDeclarationBlock * db );
+    void appendText (CodeClassFieldDeclarationBlock * db);
     void appendText (TextBlockList * items);
     void appendText (CodeMethodBlock * mb);
-    void appendText (CodeComment * comment, TextBlock * parent, UMLObject * umlObj = 0, const QString & compName="");
+    void appendText (CodeComment * comment, TextBlock * parent, UMLObject * umlObj = 0, const QString & compName = "");
     void appendText (CodeBlockWithComments * cb );
 
     // Rebuild our view of the document. Happens whenever we change
@@ -86,11 +111,14 @@ protected:
     void loadFromDocument();
 
     // specialized popup menu for our tool
-    QPopupMenu * createPopupMenu ( const QPoint & pos );
+    Q3PopupMenu * createPopupMenu(const QPoint & pos);
+    KMenu * createPopup();
+
+//    virtual void mousePressEvent(QMouseEvent * event);
 
 private:
 
-    QString parentDocName;
+    QString m_parentDocName;
     CodeDocument * m_parentDoc;
     CodeViewerDialog * m_parentDlg;
 
@@ -106,7 +134,7 @@ private:
     TextBlock * m_selectedTextBlock;
     TextBlock * m_lastTextBlockToBeEdited;
 
-    QMap<TextBlock*, TextBlockInfo*> *m_tbInfoMap;
+    QMap<TextBlock*, TextBlockInfo*> m_tbInfoMap;
     TextBlockList m_textBlockList;
 
     // main insert routine. Will append if startline is not supplied.
@@ -131,7 +159,7 @@ private:
 
     // return whether or not the passed string is empty or
     // contains nothing but whitespace
-    static bool StringIsBlank( const QString &str );
+    static bool stringIsBlank( const QString &str );
 
 public slots:
 
@@ -163,29 +191,5 @@ signals:
 
 };
 
-class ParaInfo {
-public:
-    int start; // this is a relative offset from the beginning of the tblock
-    int size;
-    QColor fgcolor;
-    QColor bgcolor;
-    bool isEditable;
-
-    ParaInfo () { isEditable = false; }
-};
-
-class TextBlockInfo {
-public:
-    QPtrList<ParaInfo> m_paraList;
-    UMLObject * m_parent;
-    QString displayName;
-    bool isClickable;
-    bool isCodeAccessorMethod;
-
-    TextBlockInfo () { m_parent = 0; isClickable = false; isCodeAccessorMethod = false; }
-    void setParent(UMLObject *p = 0) { m_parent = p; }
-    UMLObject * getParent() { return m_parent; }
-
-};
 
 #endif // CODEEDITOR_H
