@@ -12,13 +12,14 @@
 #ifndef DIAGRAMPRINTPAGE_H
 #define DIAGRAMPRINTPAGE_H
 
-class QListBox;
+class Q3ListBox;
 class QRadioButton;
-class QComboBox;
-class QButtonGroup;
-class QGroupBox;
+class Q3ButtonGroup;
+class Q3GroupBox;
 
-#include <kdeprint/kprintdialogpage.h>
+class KComboBox;
+
+#include <Q3ValueList>
 
 #include "../umldoc.h"
 #include "../umlview.h"
@@ -34,7 +35,7 @@ class QGroupBox;
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 
-class DiagramPrintPage : public KPrintDialogPage {
+class DiagramPrintPage : public QWidget {
     Q_OBJECT
 public:
     /**
@@ -46,32 +47,27 @@ public:
     DiagramPrintPage(QWidget * parent, UMLDoc *doc);
 
     /**
-     *  Stnadard deconstructor.
+     *  Standard deconstructor.
      */
     ~DiagramPrintPage();
 
     /**
-     * Overriden method. It builds a list with the diagram name and the diagram
-     * IDs.
+     * Get selected print options
      */
-    void getOptions(QMap<QString,QString>& opts, bool /* incldef=false */);
+    int printUmlCount();
+    QString printUmlDiagram(int sel);
 
     /**
-     * Overriden method.
-     */
-    void setOptions( const QMap<QString,QString>& /*opts*/ );
-
-    /**
-     * Overriden method.
+     * Overridden method.
      */
     bool isValid( QString& msg );
 
 private:
-    QButtonGroup * m_pFilterBG;
-    QGroupBox * m_pSelectGB;
-    QListBox * m_pSelectLB;
+    Q3ButtonGroup * m_pFilterBG;
+    Q3GroupBox * m_pSelectGB;
+    Q3ListBox * m_pSelectLB;
     QRadioButton * m_pAllRB, * m_pCurrentRB, * m_pSelectRB, * m_pTypeRB;
-    QComboBox * m_pTypeCB;
+    KComboBox * m_pTypeCB;
 
     UMLDoc * m_pDoc;
     Uml::Diagram_Type m_ViewType;
@@ -79,7 +75,7 @@ private:
     /**
      * list containing the IDs of diagrams to print
      */
-    QValueList<Uml::IDType> m_nIdList;
+    Q3ValueList<Uml::IDType> m_nIdList;
 
     enum FilterType{Current = 0, All, Select, Type};
 public slots:
@@ -95,7 +91,7 @@ public slots:
      * Gets called when the user chooses another diagram type. Only diagrams of
      * this type will be shown in the diagram box.
      */
-    void slotActivated(const QString & text);
+    void slotActivated(int index);
 };
 
 #endif
