@@ -12,7 +12,7 @@
 #ifndef NOTEDIALOG_H
 #define NOTEDIALOG_H
 //kde includes
-#include <kdialogbase.h>
+#include <kdialog.h>
 //app includes
 #include "../notewidget.h"
 
@@ -20,11 +20,13 @@
  * @author Paul Hensgen
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class QGroupBox;
-class QLineEdit;
-class QTextEdit;
+class Q3GroupBox;
+class Q3TextEdit;
+
+class NoteDialog : public KDialog {
+
+   Q_OBJECT
 
-class NoteDialog : public KDialogBase {
 public:
     /**
      *  Constructs an NoteDialog.
@@ -40,8 +42,8 @@ public slots:
     void slotOk();
 private:
     //GUI widgets
-    QGroupBox * m_pDocGB;
-    QTextEdit * m_pDocTE;
+    Q3GroupBox * m_pDocGB;
+    Q3TextEdit * m_pDocTE;
 
     /**
      *  Note widget to show documentation for.
