@@ -12,16 +12,18 @@
 #ifndef PARMPROPDLG_H
 #define PARMPROPDLG_H
 
-#include <kdialogbase.h>
-#include <kcombobox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qradiobutton.h>
-#include <qlineedit.h>
-#include <qbuttongroup.h>
-#include <qmultilineedit.h>
+#include <q3buttongroup.h>
+#include <q3multilineedit.h>
 #include <qcombobox.h>
+
+#include <kdialog.h>
+#include <kcombobox.h>
+#include <klineedit.h>
+
 #include "../attribute.h"
 
 class UMLDoc;
@@ -35,7 +37,7 @@ class UMLDoc;
  * @author Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class ParmPropDlg : public KDialogBase {
+class ParmPropDlg : public KDialog {
     Q_OBJECT
 public:
     /**
@@ -111,13 +113,13 @@ protected:
 
 
 private:
-    QGroupBox * m_pParmGB, * m_pDocGB;
-    QButtonGroup *m_pKind;
+    Q3GroupBox * m_pParmGB, * m_pDocGB;
+    Q3ButtonGroup *m_pKind;
     QRadioButton * m_pIn, * m_pOut, *m_pInOut;
     QLabel * m_pTypeL, * m_pNameL, * m_pInitialL, * m_pStereoTypeL;
     KComboBox * m_pTypeCB, * m_pStereoTypeCB;
-    QLineEdit * m_pNameLE, * m_pInitialLE;
-    QMultiLineEdit * m_pDoc;
+    KLineEdit * m_pNameLE, * m_pInitialLE;
+    Q3MultiLineEdit * m_pDoc;
     UMLDoc * m_pUmldoc;
     UMLAttribute * m_pAtt;
 };
