@@ -13,29 +13,31 @@
 #define STATEDIALOG_H
 
 //kde class includes
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 
 //local class includes
 #include "umlwidgetcolorpage.h"
 #include "activitypage.h"
+//Added by qt3to4:
+#include <QLabel>
 
 //forward declarations
 class UMLView;
 class StateWidget;
 class QLabel;
-class QLineEdit;
-class QMultiLineEdit;
-class QGroupBox;
+class KLineEdit;
+class Q3MultiLineEdit;
+class Q3GroupBox;
 class KFontChooser;
 
 /**
- *   Displays the properties for a @ref StateWidget
+ * Displays the properties for a @ref StateWidget
  *
- *   @author   Paul Hensgen
+ * @author   Paul Hensgen
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 
-class StateDialog : public KDialogBase {
+class StateDialog : public KPageDialog {
     Q_OBJECT
 
 public:
@@ -53,14 +55,6 @@ public:
 
 protected slots:
 
-    enum Page
-    {
-        GeneralPage = 0,
-        Activity_Page,
-        ColorPage,
-        FontPage
-    };
-
     /**
     *   Entered when OK button pressed.
     */
@@ -99,7 +93,7 @@ protected:
     /**
     *     Applys changes to the given page.
     */
-    void applyPage( Page page );
+    void applyPage( KPageWidgetItem*item );
 
     /**
     *   Font chooser widget for font page.
@@ -133,12 +127,13 @@ protected:
 
     struct GeneralPageWidgets {
         QLabel * nameL, * typeL;
-        QLineEdit * nameLE, * typeLE;
-        QMultiLineEdit * docMLE;
+        KLineEdit * nameLE, * typeLE;
+        Q3MultiLineEdit * docMLE;
 
-        QGroupBox * docGB, * generalGB;
+        Q3GroupBox * docGB, * generalGB;
     }
     m_GenPageWidgets;
+    KPageWidgetItem *pageColor,*pageActivity,*pageFont,*pageGeneral;
 };
 
 #endif
