@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2004-2006                                                *
+ *  copyright (C) 2004-2008                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -13,8 +13,8 @@
 #include "model_utils.h"
 
 // qt/kde includes
-#include <qregexp.h>
-#include <qstringlist.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kinputdialog.h>
@@ -22,6 +22,7 @@
 // app includes
 #include "umlobject.h"
 #include "umlpackagelist.h"
+#include "uniqueconstraint.h"
 #include "package.h"
 #include "folder.h"
 #include "classifier.h"
@@ -38,7 +39,8 @@
 
 namespace Model_Utils {
 
-bool isCloneable(Uml::Widget_Type type) {
+bool isCloneable(Uml::Widget_Type type)
+{
     switch (type) {
     case Uml::wt_Actor:
     case Uml::wt_UseCase:
@@ -56,9 +58,10 @@ bool isCloneable(Uml::Widget_Type type) {
     }
 }
 
-UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList) {
-    for (UMLObjectListIt oit(inList); oit.current(); ++oit) {
-        UMLObject *obj = oit.current();
+UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList)
+{
+    for (UMLObjectListIt oit(inList); oit.hasNext(); ) {
+        UMLObject *obj = oit.next();
         if (obj->getID() == id)
             return obj;
         UMLObject *o;
@@ -103,7 +106,8 @@ UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList) {
 UMLObject* findUMLObject(const UMLObjectList& inList,
                          const QString& inName,
                          Uml::Object_Type type /* = ot_UMLObject */,
-                         UMLObject *currentObj /* = NULL */) {
+                         UMLObject *currentObj /* = NULL */)
+{
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
     QString name = inName;
     QStringList components;
@@ -111,17 +115,17 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     // If we have a pointer or a reference in cpp we need to remove
     // the asterisks and ampersands in order to find the appropriate object
     if (UMLApp::app()->getActiveLanguage() == Uml::pl_Cpp) {
-        if (name.endsWith("*"))
-            name.remove("*");
-        else if (name.contains("&"))
-            name.remove("&");
+        if (name.endsWith('*'))
+            name.remove('*');
+        else if (name.contains('&'))
+            name.remove('&');
     }
 #endif
-    QString nameWithoutFirstPrefix;
     if (name.contains("::"))
-        components = QStringList::split("::", name);
-    else if (name.contains("."))
-        components = QStringList::split(".", name);
+        components = name.split("::");
+    else if (name.contains('.'))
+        components = name.split('.');
+    QString nameWithoutFirstPrefix;
     if (components.size() > 1) {
         name = components.front();
         components.pop_front();
@@ -142,41 +146,41 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
                 if (caseSensitive) {
                     if (pkg->getName() == name)
                         return pkg;
-                } else if (pkg->getName().lower() == name.lower()) {
+                } else if (pkg->getName().toLower() == name.toLower()) {
                     return pkg;
                 }
             }
-            if (seenPkgs.findRef(pkg) != -1) {
-                kError() << "findUMLObject(" << name << "): "
+            if (seenPkgs.indexOf(pkg) != -1) {
+                uError() << "findUMLObject(" << name << "): "
                     << "breaking out of cycle involving "
-                    << pkg->getName() << endl;
+                    << pkg->getName();
                 break;
             }
             seenPkgs.append(pkg);
             UMLObjectList objectsInCurrentScope = pkg->containedObjects();
-            for (UMLObjectListIt oit(objectsInCurrentScope); oit.current(); ++oit) {
-                UMLObject *obj = oit.current();
+            for (UMLObjectListIt oit(objectsInCurrentScope); oit.hasNext(); ) {
+                UMLObject *obj = oit.next();
                 if (caseSensitive) {
                     if (obj->getName() != name)
                         continue;
-                } else if (obj->getName().lower() != name.lower()) {
+                } else if (obj->getName().toLower() != name.toLower()) {
                     continue;
                 }
                 Uml::Object_Type foundType = obj->getBaseType();
                 if (nameWithoutFirstPrefix.isEmpty()) {
                     if (type != Uml::ot_UMLObject && type != foundType) {
-                        kDebug() << "findUMLObject: type mismatch for "
+                        uDebug() << "findUMLObject: type mismatch for "
                             << name << " (seeking type: "
                             << type << ", found type: "
-                            << foundType << ")" << endl;
+                            << foundType << ")";
                         // Class, Interface, and Datatype are all Classifiers
                         // and are considered equivalent.
                         // The caller must be prepared to handle possible mismatches.
                         if ((type == Uml::ot_Class ||
                              type == Uml::ot_Interface ||
                              type == Uml::ot_Datatype) &&
-                            (foundType == Uml::ot_Class || 
-                             foundType == Uml::ot_Interface || 
+                            (foundType == Uml::ot_Class ||
+                             foundType == Uml::ot_Interface ||
                              foundType == Uml::ot_Datatype)) {
                             return obj;
                         }
@@ -189,8 +193,8 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
                     foundType != Uml::ot_Class &&
                     foundType != Uml::ot_Interface &&
                     foundType != Uml::ot_Component) {
-                    kDebug() << "findUMLObject: found \"" << name
-                        << "\" is not a package (?)" << endl;
+                    uDebug() << "findUMLObject: found \"" << name
+                        << "\" is not a package (?)";
                     continue;
                 }
                 UMLPackage *pkg = static_cast<UMLPackage*>(obj);
@@ -200,21 +204,21 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
             currentObj = pkg;
         }
     }
-    for (UMLObjectListIt oit(inList); oit.current(); ++oit) {
-        UMLObject *obj = oit.current();
+    for (UMLObjectListIt oit(inList); oit.hasNext(); ) {
+        UMLObject *obj = oit.next();
         if (caseSensitive) {
             if (obj->getName() != name)
                 continue;
-        } else if (obj->getName().lower() != name.lower()) {
+        } else if (obj->getName().toLower() != name.toLower()) {
             continue;
         }
         Uml::Object_Type foundType = obj->getBaseType();
         if (nameWithoutFirstPrefix.isEmpty()) {
             if (type != Uml::ot_UMLObject && type != foundType) {
-                kDebug() << "findUMLObject: type mismatch for "
+                uDebug() << "findUMLObject: type mismatch for "
                     << name << " (seeking type: "
                     << type << ", found type: "
-                    << foundType << ")" << endl;
+                    << foundType << ")";
                 continue;
             }
             return obj;
@@ -224,8 +228,8 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
             foundType != Uml::ot_Class &&
             foundType != Uml::ot_Interface &&
             foundType != Uml::ot_Component) {
-            kDebug() << "findUMLObject: found \"" << name
-                << "\" is not a package (?)" << endl;
+            uDebug() << "findUMLObject: found \"" << name
+                << "\" is not a package (?)";
             continue;
         }
         UMLPackage *pkg = static_cast<UMLPackage*>(obj);
@@ -235,7 +239,8 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     return NULL;
 }
 
-QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString prefix) {
+QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString prefix)
+{
     QString currentName = prefix;
     if (currentName.isEmpty()) {
         if(type == Uml::ot_Class)
@@ -264,9 +269,11 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
             currentName = i18n("new_folder");
         else if(type == Uml::ot_Association)
             currentName = i18n("new_association");
+        else if(type == Uml::ot_Category)
+            currentName = i18n("new_category");
         else {
             currentName = i18n("new_object");
-            kWarning() << "unknown object type in umldoc::uniqObjectName()" << endl;
+            uWarning() << "unknown object type in umldoc::uniqObjectName()";
         }
     }
     UMLDoc *doc = UMLApp::app()->getDocument();
@@ -277,7 +284,8 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
     return name;
 }
 
-bool isCommonXMIAttribute( const QString &tag ) {
+bool isCommonXMIAttribute( const QString &tag )
+{
     bool retval = (Uml::tagEq(tag, "name") ||
                    Uml::tagEq(tag, "visibility") ||
                    Uml::tagEq(tag, "isRoot") ||
@@ -287,6 +295,7 @@ bool isCommonXMIAttribute( const QString &tag ) {
                    Uml::tagEq(tag, "isActive") ||
                    Uml::tagEq(tag, "namespace") ||
                    Uml::tagEq(tag, "ownerScope") ||
+                   Uml::tagEq(tag, "ModelElement.stereotype") ||
                    Uml::tagEq(tag, "GeneralizableElement.generalization") ||
                    Uml::tagEq(tag, "specialization") ||   //NYI
                    Uml::tagEq(tag, "clientDependency") || //NYI
@@ -295,7 +304,8 @@ bool isCommonXMIAttribute( const QString &tag ) {
     return retval;
 }
 
-bool isCommonDataType(QString type) {
+bool isCommonDataType(QString type)
+{
     CodeGenerator *gen = UMLApp::app()->getGenerator();
     if (gen == NULL)
         return false;
@@ -306,26 +316,31 @@ bool isCommonDataType(QString type) {
         if (caseSensitive) {
             if (type == *it)
                 return true;
-        } else if (type.lower() == (*it).lower()) {
+        } else if (type.toLower() == (*it).toLower()) {
             return true;
         }
     }
     return false;
 }
 
-bool isClassifierListitem(Uml::Object_Type type) {
+bool isClassifierListitem(Uml::Object_Type type)
+{
     if (type == Uml::ot_Attribute ||
         type == Uml::ot_Operation ||
         type == Uml::ot_Template ||
         type == Uml::ot_EntityAttribute ||
-        type == Uml::ot_EnumLiteral) {
+        type == Uml::ot_EnumLiteral ||
+        type == Uml::ot_UniqueConstraint ||
+        type == Uml::ot_ForeignKeyConstraint  ||
+        type == Uml::ot_CheckConstraint) {
         return true;
     } else {
         return false;
     }
 }
 
-Uml::Model_Type guessContainer(UMLObject *o) {
+Uml::Model_Type guessContainer(UMLObject *o)
+{
     Uml::Object_Type ot = o->getBaseType();
     if (ot == Uml::ot_Package && o->getStereotype() == "subsystem")
         return Uml::mt_Component;
@@ -355,6 +370,10 @@ Uml::Model_Type guessContainer(UMLObject *o) {
             break;
         case Uml::ot_Entity:
         case Uml::ot_EntityAttribute:
+        case Uml::ot_UniqueConstraint:
+        case Uml::ot_ForeignKeyConstraint:
+        case Uml::ot_CheckConstraint:
+        case Uml::ot_Category:
             mt = Uml::mt_EntityRelationship;
             break;
         case Uml::ot_Association:
@@ -388,13 +407,14 @@ Uml::Model_Type guessContainer(UMLObject *o) {
     return mt;
 }
 
-int stringToDirection(QString input, Uml::Parameter_Direction & result) {
+int stringToDirection(QString input, Uml::Parameter_Direction & result) 
+{
     QRegExp dirx("^(in|out|inout)");
-    int pos = dirx.search(input);
+    int pos = dirx.indexIn(input);
     if (pos == -1)
         return 0;
     const QString& dirStr = dirx.capturedTexts().first();
-    uint dirLen = dirStr.length();
+    int dirLen = dirStr.length();
     if (input.length() > dirLen && !input[dirLen].isSpace())
         return 0;       // no match after all.
     if (dirStr == "out")
@@ -406,15 +426,15 @@ int stringToDirection(QString input, Uml::Parameter_Direction & result) {
     return dirLen;
 }
 
-Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningScope) {
-
+Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningScope)
+{
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
-    t = t.stripWhiteSpace();
+    t = t.trimmed();
     if (t.isEmpty())
         return PS_Empty;
 
-    QStringList nameAndType = QStringList::split( QRegExp("\\s*:\\s*"), t);
+    QStringList nameAndType = t.split( QRegExp("\\s*:\\s*"));
     if (nameAndType.count() == 2) {
         UMLObject *pType = NULL;
         if (nameAndType[1] != "class") {
@@ -429,19 +449,40 @@ Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningSc
     return PS_OK;
 }
 
-Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningScope) {
+Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningScope,
+                            Uml::Visibility *vis /* = 0 */)
+{
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
-    a = a.simplifyWhiteSpace();
+    a = a.simplified();
     if (a.isEmpty())
         return PS_Empty;
 
-    int colonPos = a.find(':');
+    int colonPos = a.indexOf(':');
     if (colonPos < 0) {
         nmTp = NameAndType(a, NULL);
         return PS_OK;
     }
-    QString name = a.left(colonPos).stripWhiteSpace();
+    QString name = a.left(colonPos).trimmed();
+    if (vis) {
+        QRegExp mnemonicVis("^([\\+\\#\\-\\~] *)");
+        int pos = mnemonicVis.indexIn(name);
+        if (pos == -1) {
+            *vis = Uml::Visibility::Private;  // default value
+        } else {
+            QString caption = mnemonicVis.cap(1);
+            QString strVis = caption.left(1);
+            if (strVis == "+")
+                *vis = Uml::Visibility::Public;
+            else if (strVis == "#")
+                *vis = Uml::Visibility::Protected;
+            else if (strVis == "-")
+                *vis = Uml::Visibility::Private;
+            else
+                *vis = Uml::Visibility::Implementation;
+        }
+        name.remove(mnemonicVis);
+    }
     Uml::Parameter_Direction pd = Uml::pd_In;
     if (name.startsWith("in ")) {
         pd = Uml::pd_In;
@@ -453,12 +494,12 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
         pd = Uml::pd_Out;
         name = name.mid(4);
     }
-    a = a.mid(colonPos + 1).stripWhiteSpace();
+    a = a.mid(colonPos + 1).trimmed();
     if (a.isEmpty()) {
         nmTp = NameAndType(name, NULL, pd);
         return PS_OK;
     }
-    QStringList typeAndInitialValue = QStringList::split( QRegExp("\\s*=\\s*"), a );
+    QStringList typeAndInitialValue = a.split( QRegExp("\\s*=\\s*") );
     const QString &type = typeAndInitialValue[0];
     UMLObject *pType = pDoc->findUMLObject(type, Uml::ot_UMLObject, owningScope);
     if (pType == NULL) {
@@ -473,10 +514,11 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
     return PS_OK;
 }
 
-Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owningScope) {
+Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owningScope)
+{
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
-    m = m.simplifyWhiteSpace();
+    m = m.simplified();
     if (m.isEmpty())
         return PS_Empty;
     if (m.contains(QRegExp("operator *()"))) {
@@ -490,17 +532,17 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
          * using narrative names, for example "check water temperature".
          */
         QRegExp beginningUpToOpenParenth( "^([^\\(]+)" );
-        int pos = beginningUpToOpenParenth.search(m);
+        int pos = beginningUpToOpenParenth.indexIn(m);
         if (pos == -1)
             return PS_Illegal_MethodName;
         desc.m_name = beginningUpToOpenParenth.cap(1);
     }
     desc.m_pReturnType = NULL;
     QRegExp pat = QRegExp("\\) *:(.*)$");
-    int pos = pat.search(m);
+    int pos = pat.indexIn(m);
     if (pos != -1) {  // return type is optional
         QString retType = pat.cap(1);
-        retType = retType.stripWhiteSpace();
+        retType = retType.trimmed();
         if (retType != "void") {
             UMLObject *pRetType = owningScope->findTemplate(retType);
             if (pRetType == NULL) {
@@ -515,14 +557,14 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     m.remove( QRegExp("\\s*\\(\\s*\\)") );
     desc.m_args.clear();
     pat = QRegExp( "\\((.*)\\)" );
-    pos = pat.search(m);
+    pos = pat.indexIn(m);
     if (pos == -1)  // argument list is optional
         return PS_OK;
     QString arglist = pat.cap(1);
-    arglist = arglist.stripWhiteSpace();
+    arglist = arglist.trimmed();
     if (arglist.isEmpty())
         return PS_OK;
-    QStringList args = QStringList::split( QRegExp("\\s*,\\s*"), arglist);
+    QStringList args = arglist.split( QRegExp("\\s*,\\s*") );
     for (QStringList::Iterator lit = args.begin(); lit != args.end(); ++lit) {
         NameAndType nmTp;
         Parse_Status ps = parseAttribute(*lit, nmTp, owningScope);
@@ -533,16 +575,35 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     return PS_OK;
 }
 
-QString psText(Parse_Status value) {
+Parse_Status parseConstraint(QString m, QString& name, UMLEntity* owningScope)
+{
+    Q_UNUSED(owningScope);
+    m = m.simplified();
+    if (m.isEmpty())
+        return PS_Empty;
+
+    int colonPos = m.indexOf(':');
+    if (colonPos < 0) {
+        name = m;
+        return PS_OK;
+    }
+
+    name = m.left(colonPos).trimmed();
+    return PS_OK;
+}
+
+QString psText(Parse_Status value)
+{
     const QString text[] = {
-                               i18n("OK"), i18n("Empty"), i18n("Malformed argument"),
+                               i18n("OK"), i18nc("parse status", "Empty"), i18n("Malformed argument"),
                                i18n("Unknown argument type"), i18n("Illegal method name"),
                                i18n("Unknown return type"), i18n("Unspecified error")
                            };
     return text[(unsigned) value];
 }
 
-QString progLangToString(Uml::Programming_Language pl) {
+QString progLangToString(Uml::Programming_Language pl)
+{
     switch (pl) {
         case Uml::pl_ActionScript:
             return "ActionScript";
@@ -550,14 +611,18 @@ QString progLangToString(Uml::Programming_Language pl) {
             return "Ada";
         case Uml::pl_Cpp:
             return "C++";
-        // case Uml::pl_Csharp:
-            // return "C#";
+        case Uml::pl_CSharp:
+            return "C#";
+        case Uml::pl_D:
+            return "D";
         case Uml::pl_IDL:
             return "IDL";
         case Uml::pl_Java:
             return "Java";
         case Uml::pl_JavaScript:
             return "JavaScript";
+        case Uml::pl_MySQL:
+             return "MySQL";
         case Uml::pl_Pascal:
             return "Pascal";
         case Uml::pl_Perl:
@@ -566,6 +631,8 @@ QString progLangToString(Uml::Programming_Language pl) {
             return "PHP";
         case Uml::pl_PHP5:
             return "PHP5";
+        case Uml::pl_PostgreSQL:
+            return "PostgreSQL";
         case Uml::pl_Python:
             return "Python";
         case Uml::pl_Ruby:
@@ -579,24 +646,29 @@ QString progLangToString(Uml::Programming_Language pl) {
         default:
             break;
     }
-    return QString::null;
+    return QString();
 }
 
-Uml::Programming_Language stringToProgLang(QString str) {
+Uml::Programming_Language stringToProgLang(QString str)
+{
     if (str == "ActionScript")
         return Uml::pl_ActionScript;
     if (str == "Ada")
         return Uml::pl_Ada;
     if (str == "C++" || str == "Cpp")  // "Cpp" only for bkwd compatibility
         return Uml::pl_Cpp;
-    // if (str == "C#")
-        // return Uml::pl_Csharp;
+    if (str == "C#")
+        return Uml::pl_CSharp;
+    if (str == "D")
+        return Uml::pl_D;
     if (str == "IDL")
         return Uml::pl_IDL;
     if (str == "Java")
         return Uml::pl_Java;
     if (str == "JavaScript")
         return Uml::pl_JavaScript;
+    if (str == "MySQL")
+        return Uml::pl_MySQL;
     if (str == "Pascal")
         return Uml::pl_Pascal;
     if (str == "Perl")
@@ -605,6 +677,8 @@ Uml::Programming_Language stringToProgLang(QString str) {
         return Uml::pl_PHP;
     if (str == "PHP5")
         return Uml::pl_PHP5;
+    if (str == "PostgreSQL")
+        return Uml::pl_PostgreSQL;
     if (str == "Python")
         return Uml::pl_Python;
     if (str == "Ruby")
@@ -618,7 +692,8 @@ Uml::Programming_Language stringToProgLang(QString str) {
     return Uml::pl_Reserved;
 }
 
-bool typeIsRootView(Uml::ListView_Type type) {
+bool typeIsRootView(Uml::ListView_Type type)
+{
     switch (type) {
         case Uml::lvt_View:
         case Uml::lvt_Logical_View:
@@ -634,7 +709,8 @@ bool typeIsRootView(Uml::ListView_Type type) {
     return false;
 }
 
-bool typeIsCanvasWidget(Uml::ListView_Type type) {
+bool typeIsCanvasWidget(Uml::ListView_Type type)
+{
     switch (type) {
         case Uml::lvt_Actor:
         case Uml::lvt_UseCase:
@@ -653,6 +729,7 @@ bool typeIsCanvasWidget(Uml::ListView_Type type) {
         case Uml::lvt_Datatype:
         case Uml::lvt_Enum:
         case Uml::lvt_Entity:
+        case Uml::lvt_Category:
             return true;
             break;
         default:
@@ -661,7 +738,8 @@ bool typeIsCanvasWidget(Uml::ListView_Type type) {
     return false;
 }
 
-bool typeIsFolder(Uml::ListView_Type type) {
+bool typeIsFolder(Uml::ListView_Type type)
+{
     if (typeIsRootView(type) ||
             type == Uml::lvt_Datatype_Folder ||
             type == Uml::lvt_Logical_Folder ||
@@ -675,7 +753,8 @@ bool typeIsFolder(Uml::ListView_Type type) {
     }
 }
 
-bool typeIsContainer(Uml::ListView_Type type) {
+bool typeIsContainer(Uml::ListView_Type type)
+{
     if (typeIsFolder(type))
         return true;
     return (type == Uml::lvt_Package ||
@@ -683,11 +762,16 @@ bool typeIsContainer(Uml::ListView_Type type) {
             type == Uml::lvt_Component);
 }
 
-bool typeIsClassifierList(Uml::ListView_Type type) {
+bool typeIsClassifierList(Uml::ListView_Type type)
+{
     if (type == Uml::lvt_Attribute ||
         type == Uml::lvt_Operation ||
         type == Uml::lvt_Template ||
         type == Uml::lvt_EntityAttribute ||
+        type == Uml::lvt_UniqueConstraint ||
+        type == Uml::lvt_ForeignKeyConstraint ||
+        type == Uml::lvt_PrimaryKeyConstraint ||
+        type == Uml::lvt_CheckConstraint  ||
         type == Uml::lvt_EnumLiteral) {
         return true;
     } else {
@@ -695,7 +779,19 @@ bool typeIsClassifierList(Uml::ListView_Type type) {
     }
 }
 
-bool typeIsDiagram(Uml::ListView_Type type) {
+bool typeIsClassifier(Uml::ListView_Type type)
+{
+    if ( type == Uml::lvt_Class ||
+         type == Uml::lvt_Interface ||
+         type == Uml::lvt_Entity ||
+         type == Uml::lvt_Enum ) {
+        return true;
+    }
+    return false;
+}
+
+bool typeIsDiagram(Uml::ListView_Type type)
+{
     if (type == Uml::lvt_Class_Diagram ||
             type == Uml::lvt_Collaboration_Diagram ||
             type == Uml::lvt_State_Diagram ||
@@ -711,7 +807,8 @@ bool typeIsDiagram(Uml::ListView_Type type) {
     }
 }
 
-Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt) {
+Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt)
+{
     Uml::Model_Type mt;
     switch (dt) {
         case Uml::dt_UseCase:
@@ -734,14 +831,15 @@ Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt) {
             mt = Uml::mt_EntityRelationship;
             break;
         default:
-            kError() << "Model_Utils::convert_DT_MT: illegal input value " << dt << endl;
+            uError() << "Model_Utils::convert_DT_MT: illegal input value " << dt;
             mt = Uml::N_MODELTYPES;
             break;
     }
     return mt;
 }
 
-Uml::ListView_Type convert_MT_LVT(Uml::Model_Type mt) {
+Uml::ListView_Type convert_MT_LVT(Uml::Model_Type mt)
+{
     Uml::ListView_Type lvt = Uml::lvt_Unknown;
     switch (mt) {
         case Uml::mt_Logical:
@@ -765,7 +863,8 @@ Uml::ListView_Type convert_MT_LVT(Uml::Model_Type mt) {
     return lvt;
 }
 
-Uml::Model_Type convert_LVT_MT(Uml::ListView_Type lvt) {
+Uml::Model_Type convert_LVT_MT(Uml::ListView_Type lvt)
+{
     Uml::Model_Type mt = Uml::N_MODELTYPES;
     switch (lvt) {
         case Uml::lvt_Logical_View:
@@ -789,7 +888,8 @@ Uml::Model_Type convert_LVT_MT(Uml::ListView_Type lvt) {
     return mt;
 }
 
-Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt) {
+Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt)
+{
     Uml::ListView_Type type =  Uml::lvt_Unknown;
     switch(dt) {
     case Uml::dt_UseCase:
@@ -829,12 +929,13 @@ Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt) {
         break;
 
     default:
-        kWarning() << "convert_DT_LVT() called on unknown diagram type" << endl;
+        uWarning() << "convert_DT_LVT() called on unknown diagram type";
     }
     return type;
 }
 
-Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
+Uml::ListView_Type convert_OT_LVT(UMLObject *o)
+{
     Uml::Object_Type ot = o->getBaseType();
     Uml::ListView_Type type =  Uml::lvt_Unknown;
     switch(ot) {
@@ -883,9 +984,8 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
                     return type;
                 }
             } while ((f = static_cast<UMLFolder*>(f->getUMLPackage())) != NULL);
-            kError() << "convert_OT_LVT(" << o->getName()
-                << "): internal error - object is not properly nested in folder"
-                << endl;
+            uError() << "convert_OT_LVT(" << o->getName()
+                << "): internal error - object is not properly nested in folder";
         }
         break;
 
@@ -921,10 +1021,33 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
         type = Uml::lvt_Entity;
         break;
 
+    case Uml::ot_Category:
+        type = Uml::lvt_Category;
+        break;
+
     case Uml::ot_EntityAttribute:
         type = Uml::lvt_EntityAttribute;
         break;
 
+    case Uml::ot_UniqueConstraint: {
+         UMLEntity* ent = static_cast<UMLEntity*>(o->parent());
+         UMLUniqueConstraint* uc = static_cast<UMLUniqueConstraint*>( o );
+         if ( ent->isPrimaryKey( uc ) ) {
+             type = Uml::lvt_PrimaryKeyConstraint;
+         } else {
+             type = Uml::lvt_UniqueConstraint;
+         }
+         break;
+        }
+
+    case Uml::ot_ForeignKeyConstraint:
+        type = Uml::lvt_ForeignKeyConstraint;
+        break;
+
+    case Uml::ot_CheckConstraint:
+        type = Uml::lvt_CheckConstraint;
+        break;
+
     case Uml::ot_Attribute:
         type = Uml::lvt_Attribute;
         break;
@@ -942,7 +1065,8 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o) {
     return type;
 }
 
-Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt) {
+Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt)
+{
     Uml::Object_Type ot = (Uml::Object_Type)0;
     switch (lvt) {
     case Uml::lvt_UseCase:
@@ -990,10 +1114,30 @@ Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt) {
         ot = Uml::ot_Entity;
         break;
 
+    case Uml::lvt_Category:
+        ot = Uml::ot_Category;
+        break;
+
     case Uml::lvt_EntityAttribute:
         ot = Uml::ot_EntityAttribute;
         break;
 
+    case Uml::lvt_UniqueConstraint:
+        ot = Uml::ot_UniqueConstraint;
+        break;
+
+    case Uml::lvt_PrimaryKeyConstraint:
+        ot = Uml::ot_UniqueConstraint;
+        break;
+
+    case Uml::lvt_ForeignKeyConstraint:
+        ot = Uml::ot_ForeignKeyConstraint;
+        break;
+
+    case Uml::lvt_CheckConstraint:
+        ot = Uml::ot_CheckConstraint;
+        break;
+
     case Uml::lvt_Attribute:
         ot = Uml::ot_Attribute;
         break;
@@ -1018,111 +1162,126 @@ Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt) {
     return ot;
 }
 
-Uml::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt) {
-    Uml::Icon_Type icon = Uml::it_Home;
+Icon_Utils::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt)
+{
+    Icon_Utils::Icon_Type icon = Icon_Utils::it_Home;
     switch (lvt) {
         case Uml::lvt_UseCase_View:
         case Uml::lvt_UseCase_Folder:
-            icon = Uml::it_Folder_Grey;
+            icon = Icon_Utils::it_Folder_Grey;
             break;
         case Uml::lvt_Logical_View:
         case Uml::lvt_Logical_Folder:
-            icon = Uml::it_Folder_Green;
+            icon = Icon_Utils::it_Folder_Green;
             break;
         case Uml::lvt_Datatype_Folder:
-            icon = Uml::it_Folder_Orange;
+            icon = Icon_Utils::it_Folder_Orange;
             break;
         case Uml::lvt_Component_View:
         case Uml::lvt_Component_Folder:
-            icon = Uml::it_Folder_Red;
+            icon = Icon_Utils::it_Folder_Red;
             break;
         case Uml::lvt_Deployment_View:
         case Uml::lvt_Deployment_Folder:
-            icon = Uml::it_Folder_Violet;
+            icon = Icon_Utils::it_Folder_Violet;
             break;
         case Uml::lvt_EntityRelationship_Model:
         case Uml::lvt_EntityRelationship_Folder:
-            icon = Uml::it_Folder_Cyan;
+            icon = Icon_Utils::it_Folder_Cyan;
             break;
 
         case Uml::lvt_Actor:
-            icon = Uml::it_Actor;
+            icon = Icon_Utils::it_Actor;
             break;
         case Uml::lvt_UseCase:
-            icon = Uml::it_UseCase;
+            icon = Icon_Utils::it_UseCase;
             break;
         case Uml::lvt_Class:
-            icon = Uml::it_Class;
+            icon = Icon_Utils::it_Class;
             break;
         case Uml::lvt_Package:
-            icon = Uml::it_Package;
+            icon = Icon_Utils::it_Package;
             break;
         case Uml::lvt_Subsystem:
-            icon = Uml::it_Subsystem;
+            icon = Icon_Utils::it_Subsystem;
             break;
         case Uml::lvt_Component:
-            icon = Uml::it_Component;
+            icon = Icon_Utils::it_Component;
             break;
         case Uml::lvt_Node:
-            icon = Uml::it_Node;
+            icon = Icon_Utils::it_Node;
             break;
         case Uml::lvt_Artifact:
-            icon = Uml::it_Artifact;
+            icon = Icon_Utils::it_Artifact;
             break;
         case Uml::lvt_Interface:
-            icon = Uml::it_Interface;
+            icon = Icon_Utils::it_Interface;
             break;
         case Uml::lvt_Datatype:
-            icon = Uml::it_Datatype;
+            icon = Icon_Utils::it_Datatype;
             break;
         case Uml::lvt_Enum:
-            icon = Uml::it_Enum;
+            icon = Icon_Utils::it_Enum;
             break;
         case Uml::lvt_Entity:
-            icon = Uml::it_Entity;
+            icon = Icon_Utils::it_Entity;
+            break;
+        case Uml::lvt_Category:
+            icon = Icon_Utils::it_Category;
             break;
         case Uml::lvt_Template:
-            icon = Uml::it_Template;
+            icon = Icon_Utils::it_Template;
             break;
         case Uml::lvt_Attribute:
-            icon = Uml::it_Private_Attribute;
+            icon = Icon_Utils::it_Private_Attribute;
             break;
         case Uml::lvt_EntityAttribute:
-            icon = Uml::it_Private_Attribute;
+            icon = Icon_Utils::it_Private_Attribute;
             break;
         case Uml::lvt_EnumLiteral:
-            icon = Uml::it_Public_Attribute;
+            icon = Icon_Utils::it_Public_Attribute;
             break;
         case Uml::lvt_Operation:
-            icon = Uml::it_Public_Method;
+            icon = Icon_Utils::it_Public_Method;
+            break;
+        case Uml::lvt_UniqueConstraint:
+            icon = Icon_Utils::it_Unique_Constraint;
+            break;
+        case Uml::lvt_PrimaryKeyConstraint:
+            icon = Icon_Utils::it_PrimaryKey_Constraint;
+            break;
+        case Uml::lvt_ForeignKeyConstraint:
+            icon = Icon_Utils::it_ForeignKey_Constraint;
+            break;
+        case Uml::lvt_CheckConstraint:
+            icon = Icon_Utils::it_Check_Constraint;
             break;
-
         case Uml::lvt_Class_Diagram:
-            icon = Uml::it_Diagram_Class;
+            icon = Icon_Utils::it_Diagram_Class;
             break;
         case Uml::lvt_UseCase_Diagram:
-            icon = Uml::it_Diagram_Usecase;
+            icon = Icon_Utils::it_Diagram_Usecase;
             break;
         case Uml::lvt_Sequence_Diagram:
-            icon = Uml::it_Diagram_Sequence;
+            icon = Icon_Utils::it_Diagram_Sequence;
             break;
         case Uml::lvt_Collaboration_Diagram:
-            icon = Uml::it_Diagram_Collaboration;
+            icon = Icon_Utils::it_Diagram_Collaboration;
             break;
         case Uml::lvt_State_Diagram:
-            icon = Uml::it_Diagram_State;
+            icon = Icon_Utils::it_Diagram_State;
             break;
         case Uml::lvt_Activity_Diagram:
-            icon = Uml::it_Diagram_Activity;
+            icon = Icon_Utils::it_Diagram_Activity;
             break;
         case Uml::lvt_Component_Diagram:
-            icon = Uml::it_Diagram_Component;
+            icon = Icon_Utils::it_Diagram_Component;
             break;
         case Uml::lvt_Deployment_Diagram:
-            icon = Uml::it_Diagram_Deployment;
+            icon = Icon_Utils::it_Diagram_Deployment;
             break;
         case Uml::lvt_EntityRelationship_Diagram:
-            icon = Uml::it_Diagram_EntityRelationship;
+            icon = Icon_Utils::it_Diagram_EntityRelationship;
             break;
 
         default:
@@ -1131,7 +1290,8 @@ Uml::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt) {
     return icon;
 }
 
-Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt) {
+Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt)
+{
     Uml::Diagram_Type dt = Uml::dt_Undefined;
     switch (lvt) {
         case Uml::lvt_Class_Diagram:
@@ -1167,7 +1327,8 @@ Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt) {
     return dt;
 }
 
-Uml::Model_Type convert_OT_MT(Uml::Object_Type ot) {
+Uml::Model_Type convert_OT_MT(Uml::Object_Type ot)
+{
     Uml::Model_Type mt = Uml::N_MODELTYPES;
     switch (ot) {
         case Uml::ot_Actor:
@@ -1183,6 +1344,10 @@ Uml::Model_Type convert_OT_MT(Uml::Object_Type ot) {
             break;
         case Uml::ot_Entity:
         case Uml::ot_EntityAttribute:
+        case Uml::ot_UniqueConstraint:
+        case Uml::ot_ForeignKeyConstraint:
+        case Uml::ot_CheckConstraint:
+        case Uml::ot_Category:
             mt = Uml::mt_EntityRelationship;
             break;
         default:
@@ -1192,5 +1357,49 @@ Uml::Model_Type convert_OT_MT(Uml::Object_Type ot) {
     return mt;
 }
 
+QString updateDeleteActionToString( UMLForeignKeyConstraint::UpdateDeleteAction uda )
+{
+    switch( uda ) {
+     case UMLForeignKeyConstraint::uda_NoAction:
+         return "NO ACTION";
+     case  UMLForeignKeyConstraint::uda_Restrict:
+         return "RESTRICT";
+     case UMLForeignKeyConstraint::uda_Cascade:
+         return "CASCADE";
+     case  UMLForeignKeyConstraint::uda_SetNull:
+         return "SET NULL";
+     case  UMLForeignKeyConstraint::uda_SetDefault:
+         return "SET DEFAULT";
+     default:
+         return QString();
+    }
+}
+
+QString diagramTypeToString(Uml::Diagram_Type dt)
+{
+    switch( dt ) {
+       case Uml::dt_Class:
+           return i18n( "Class Diagram" );
+       case Uml::dt_UseCase:
+           return i18n( "Use Case Diagram" );
+       case Uml::dt_Sequence:
+           return i18n( "Sequence Diagram" );
+       case Uml::dt_Collaboration:
+           return i18n( "Collaboration Diagram" );
+       case Uml::dt_State:
+           return i18n( "State Diagram" );
+       case Uml::dt_Activity:
+           return i18n( "Activity Diagram" );
+       case Uml::dt_Component:
+           return i18n( "Component Diagram" );
+       case Uml::dt_Deployment:
+           return i18n( "Deployment Diagram" );
+       case Uml::dt_EntityRelationship:
+           return i18n( "Entity Relationship Diagram" );
+       default:
+           return i18n( "No Diagram" );
+    }
+}
+
 }  // namespace Model_Utils
 
